searchData={"items":[{"type":"module","title":"DeribitEx","doc":"DeribitEx is an Elixir library for interacting with the Deribit cryptocurrency exchange API via WebSocket.\n\nThis library handles the following:\n\n- Authentication and token management\n- WebSocket communication\n- JSON-RPC request/response formatting\n- Subscriptions and notifications\n- Rate limiting\n- Time synchronization\n- Cancel-on-disconnect safety\n\nThe main entry point for most users will be `DeribitEx.Client`.","ref":"DeribitEx.html"},{"type":"module","title":"Architecture - DeribitEx","doc":"DeribitEx consists of several components:\n\n- **Client**: High-level API interface for interacting with Deribit\n- **RPC**: Manages JSON-RPC message formatting and parsing\n- **Adapter**: Implements WebsockexNova adapter for WebSocket communication\n- **TokenManager**: Handles authentication token lifecycle\n- **ResubscriptionHandler**: Manages automatic channel resubscription\n- **TimeSyncService**: Synchronizes local and server time\n- **RateLimitHandler**: Implements adaptive rate limiting","ref":"DeribitEx.html#module-architecture"},{"type":"module","title":"Usage Example - DeribitEx","doc":"```elixir\n# Connect to Deribit\n{:ok, client} = DeribitEx.Client.connect(\n  client_id: \"your_client_id\",\n  client_secret: \"your_client_secret\"\n)\n\n# Make requests\n{:ok, instruments} = DeribitEx.Client.get_instruments(client, %{\n  currency: \"BTC\"\n})\n\n# Subscribe to channels\n{:ok, sub_id} = DeribitEx.Client.subscribe_book(\n  client,\n  \"BTC-PERPETUAL\",\n  self()\n)\n```\n\nSee the README and module documentation for more details.","ref":"DeribitEx.html#module-usage-example"},{"type":"function","title":"DeribitEx.version/0","doc":"Returns the current version of the DeribitEx library.","ref":"DeribitEx.html#version/0"},{"type":"function","title":"Examples - DeribitEx.version/0","doc":"iex> DeribitEx.version()\n    \"0.1.0\"","ref":"DeribitEx.html#version/0-examples"},{"type":"module","title":"DeribitEx.AdapterExtensions","doc":"Extensions to the Adapter for integration with token management.\n\nThis module contains the functions needed to modify Adapter \nto integrate with the token management system without directly modifying\nthe adapter itself.\n\nWhen MM0207 is fully integrated, these functions should be moved\ndirectly into the Adapter module.","ref":"DeribitEx.AdapterExtensions.html"},{"type":"function","title":"DeribitEx.AdapterExtensions.enhanced_process_method_specific_request/4","doc":"Enhances process_method_specific_request to handle resubscription after authentication.\n\nThis function adds resubscription handling to the existing process_method_specific_request function.","ref":"DeribitEx.AdapterExtensions.html#enhanced_process_method_specific_request/4"},{"type":"function","title":"DeribitEx.AdapterExtensions.get_active_orders/1","doc":"Gets all active orders from the token manager.\n\nUse this function to access active orders.","ref":"DeribitEx.AdapterExtensions.html#get_active_orders/1"},{"type":"function","title":"DeribitEx.AdapterExtensions.handle_reconnect_authenticated/1","doc":"Handles resubscription after reconnection and authentication.\n\nCall this function after handling reconnection with authentication.","ref":"DeribitEx.AdapterExtensions.html#handle_reconnect_authenticated/1"},{"type":"function","title":"DeribitEx.AdapterExtensions.init_with_token_manager/1","doc":"Extends Adapter.init/1 to initialize the token manager.\n\nCall this function from Adapter.init/1 to add token manager to state.","ref":"DeribitEx.AdapterExtensions.html#init_with_token_manager/1"},{"type":"function","title":"DeribitEx.AdapterExtensions.register_order_with_token_manager/2","doc":"Registers an order with the token manager.\n\nCall this function when creating a new order.","ref":"DeribitEx.AdapterExtensions.html#register_order_with_token_manager/2"},{"type":"function","title":"DeribitEx.AdapterExtensions.register_subscription_with_token_manager/4","doc":"Registers a subscription with the token manager.\n\nCall this function from Adapter.handle_subscription_response/2 after state updates.","ref":"DeribitEx.AdapterExtensions.html#register_subscription_with_token_manager/4"},{"type":"function","title":"DeribitEx.AdapterExtensions.unregister_subscription_from_token_manager/2","doc":"Unregisters a subscription from the token manager.\n\nCall this function when unsubscribing from a channel.","ref":"DeribitEx.AdapterExtensions.html#unregister_subscription_from_token_manager/2"},{"type":"function","title":"DeribitEx.AdapterExtensions.update_order_in_token_manager/2","doc":"Updates an order in the token manager.\n\nCall this function when order status changes.","ref":"DeribitEx.AdapterExtensions.html#update_order_in_token_manager/2"},{"type":"function","title":"DeribitEx.AdapterExtensions.update_token_manager_from_auth/2","doc":"Extends Adapter.handle_auth_response/2 to integrate with token manager.\n\nCall this function from Adapter.handle_auth_response/2 after state updates.","ref":"DeribitEx.AdapterExtensions.html#update_token_manager_from_auth/2"},{"type":"function","title":"DeribitEx.AdapterExtensions.update_token_manager_from_exchange/3","doc":"Extends Adapter.handle_exchange_token_response/2 to integrate with token manager.\n\nCall this function from Adapter.handle_exchange_token_response/2 after state updates.","ref":"DeribitEx.AdapterExtensions.html#update_token_manager_from_exchange/3"},{"type":"function","title":"DeribitEx.AdapterExtensions.update_token_manager_from_fork/3","doc":"Extends Adapter.handle_fork_token_response/2 to integrate with token manager.\n\nCall this function from Adapter.handle_fork_token_response/2 after state updates.","ref":"DeribitEx.AdapterExtensions.html#update_token_manager_from_fork/3"},{"type":"function","title":"DeribitEx.AdapterExtensions.update_token_manager_from_logout/1","doc":"Extends Adapter.handle_logout_response/2 to integrate with token manager.\n\nCall this function from Adapter.handle_logout_response/2 after state updates.","ref":"DeribitEx.AdapterExtensions.html#update_token_manager_from_logout/1"},{"type":"module","title":"DeribitEx.AdapterIntegration","doc":"Integration file to add token management to Adapter.\n\nThis module provides a structured approach to patching Adapter with\ntoken management functionality. Using this approach ensures better migration\ncontrol than directly modifying Adapter.ex.","ref":"DeribitEx.AdapterIntegration.html"},{"type":"module","title":"Usage - DeribitEx.AdapterIntegration","doc":"Add the following line to the application.ex start function to apply patches:\n\n```elixir\nDeribitEx.AdapterIntegration.apply_patches()\n```","ref":"DeribitEx.AdapterIntegration.html#module-usage"},{"type":"function","title":"DeribitEx.AdapterIntegration.apply_patches/0","doc":"Applies all token management patches to Adapter.\n\nThis function would set up function replacements, but for now it's just\na placeholder since the :meck library is not included in the project.","ref":"DeribitEx.AdapterIntegration.html#apply_patches/0"},{"type":"function","title":"DeribitEx.AdapterIntegration.get_tracked_request/2","doc":"Gets tracked request using response ID.\n\nHelper function for integration tests.","ref":"DeribitEx.AdapterIntegration.html#get_tracked_request/2"},{"type":"function","title":"DeribitEx.AdapterIntegration.is_auth_response?/1","doc":"Checks if a message is an auth response.\n\nHelper function for integration tests.","ref":"DeribitEx.AdapterIntegration.html#is_auth_response?/1"},{"type":"module","title":"DeribitEx.Adapter","doc":"WebsockexNova adapter for the Deribit WebSocket API.\n\nHandles connection, authentication, and message processing\nspecifically for the Deribit JSON-RPC WebSocket protocol.","ref":"DeribitEx.Adapter.html"},{"type":"function","title":"DeribitEx.Adapter.connection_info/1","doc":"Provides connection configuration for the WebsockexNova client.\n\nMerges provided options with sensible defaults for Deribit connection.\n\nConfigures optimal authentication refresh thresholds based on Deribit's\ntoken expiration patterns. Tokens typically last 900 seconds, and \nrefresh begins at the configured threshold before expiration.","ref":"DeribitEx.Adapter.html#connection_info/1"},{"type":"function","title":"DeribitEx.Adapter.generate_auth_data/1","doc":"Generates authentication data for Deribit API.\n\nUses client credentials from the connection state\nto create a proper Deribit authentication request.","ref":"DeribitEx.Adapter.html#generate_auth_data/1"},{"type":"function","title":"DeribitEx.Adapter.generate_disable_cod_data/2","doc":"Generates data for the disable_cancel_on_disconnect operation.\n\nThis function prepares the JSON-RPC request for the private/disable_cancel_on_disconnect\nendpoint, which disables automatic cancellation of orders on disconnection.","ref":"DeribitEx.Adapter.html#generate_disable_cod_data/2"},{"type":"function","title":"Parameters - DeribitEx.Adapter.generate_disable_cod_data/2","doc":"- `params` - Parameters for disabling COD (optional scope)\n- `state` - The current adapter state","ref":"DeribitEx.Adapter.html#generate_disable_cod_data/2-parameters"},{"type":"function","title":"Returns - DeribitEx.Adapter.generate_disable_cod_data/2","doc":"- `{:ok, encoded_request, updated_state}` - The JSON request and updated state","ref":"DeribitEx.Adapter.html#generate_disable_cod_data/2-returns"},{"type":"function","title":"DeribitEx.Adapter.generate_disable_heartbeat_data/2","doc":"Generates data for the disable_heartbeat operation.\n\nThis function prepares the JSON-RPC request for the public/disable_heartbeat \nendpoint, which disables server heartbeat messages for the connection.","ref":"DeribitEx.Adapter.html#generate_disable_heartbeat_data/2"},{"type":"function","title":"Parameters - DeribitEx.Adapter.generate_disable_heartbeat_data/2","doc":"- `params` - Parameters (unused but kept for consistency)\n- `state` - The current adapter state","ref":"DeribitEx.Adapter.html#generate_disable_heartbeat_data/2-parameters"},{"type":"function","title":"Returns - DeribitEx.Adapter.generate_disable_heartbeat_data/2","doc":"- `{:ok, encoded_request, updated_state}` - The JSON request and updated state","ref":"DeribitEx.Adapter.html#generate_disable_heartbeat_data/2-returns"},{"type":"function","title":"DeribitEx.Adapter.generate_enable_cod_data/2","doc":"Generates data for the enable_cancel_on_disconnect operation.\n\nThis function prepares the JSON-RPC request for the private/enable_cancel_on_disconnect\nendpoint, which enables automatic cancellation of orders on disconnection.","ref":"DeribitEx.Adapter.html#generate_enable_cod_data/2"},{"type":"function","title":"Parameters - DeribitEx.Adapter.generate_enable_cod_data/2","doc":"- `params` - Parameters for COD, includes the scope (connection or account)\n- `state` - The current adapter state","ref":"DeribitEx.Adapter.html#generate_enable_cod_data/2-parameters"},{"type":"function","title":"Returns - DeribitEx.Adapter.generate_enable_cod_data/2","doc":"- `{:ok, encoded_request, updated_state}` - The JSON request and updated state","ref":"DeribitEx.Adapter.html#generate_enable_cod_data/2-returns"},{"type":"function","title":"DeribitEx.Adapter.generate_exchange_token_data/2","doc":"Generates data for token exchange operation.\n\nThis function creates the payload for the public/exchange_token RPC method\nused to generate a new access token for switching subaccounts.","ref":"DeribitEx.Adapter.html#generate_exchange_token_data/2"},{"type":"function","title":"DeribitEx.Adapter.generate_fork_token_data/2","doc":"Generates data for token fork operation.\n\nThis function creates the payload for the public/fork_token RPC method\nused to create a new named session via refresh token.","ref":"DeribitEx.Adapter.html#generate_fork_token_data/2"},{"type":"function","title":"DeribitEx.Adapter.generate_get_cod_data/2","doc":"Generates data for the get_cancel_on_disconnect operation.\n\nThis function prepares the JSON-RPC request for the private/get_cancel_on_disconnect\nendpoint, which gets the status of automatic order cancellation on disconnection.","ref":"DeribitEx.Adapter.html#generate_get_cod_data/2"},{"type":"function","title":"Parameters - DeribitEx.Adapter.generate_get_cod_data/2","doc":"- `params` - Parameters for getting COD (no additional parameters needed)\n- `state` - The current adapter state","ref":"DeribitEx.Adapter.html#generate_get_cod_data/2-parameters"},{"type":"function","title":"Returns - DeribitEx.Adapter.generate_get_cod_data/2","doc":"- `{:ok, encoded_request, updated_state}` - The JSON request and updated state","ref":"DeribitEx.Adapter.html#generate_get_cod_data/2-returns"},{"type":"function","title":"DeribitEx.Adapter.generate_logout_data/2","doc":"Generates data for logout operation.\n\nThis function creates the payload for the private/logout RPC method\nused to gracefully close the session and optionally invalidate tokens.","ref":"DeribitEx.Adapter.html#generate_logout_data/2"},{"type":"function","title":"Parameters - DeribitEx.Adapter.generate_logout_data/2","doc":"- `params` - Parameters for the logout request:\n  - `\"invalidate_token\"` - Whether to invalidate all tokens (defaults to true)\n- `state` - Current adapter state containing the access token","ref":"DeribitEx.Adapter.html#generate_logout_data/2-parameters"},{"type":"function","title":"Returns - DeribitEx.Adapter.generate_logout_data/2","doc":"- `{:ok, payload, updated_state}` - The JSON-RPC request as a string and updated state\n- Raises an error if no access token is found in the state","ref":"DeribitEx.Adapter.html#generate_logout_data/2-returns"},{"type":"function","title":"Examples - DeribitEx.Adapter.generate_logout_data/2","doc":"# Generate payload to logout and invalidate tokens\n    params = %{\"invalidate_token\" => true}\n    {:ok, payload, updated_state} = generate_logout_data(params, state)\n\n    # Generate payload to logout without invalidating tokens\n    params = %{\"invalidate_token\" => false}\n    {:ok, payload, updated_state} = generate_logout_data(params, state)","ref":"DeribitEx.Adapter.html#generate_logout_data/2-examples"},{"type":"function","title":"DeribitEx.Adapter.generate_set_heartbeat_data/2","doc":"Generates data for the set_heartbeat operation.\n\nThis function prepares the JSON-RPC request for the public/set_heartbeat \nendpoint, which enables server heartbeat messages for the connection.","ref":"DeribitEx.Adapter.html#generate_set_heartbeat_data/2"},{"type":"function","title":"Parameters - DeribitEx.Adapter.generate_set_heartbeat_data/2","doc":"- `params` - Parameters containing at least the heartbeat interval in seconds (minimum 10s)\n- `state` - The current adapter state","ref":"DeribitEx.Adapter.html#generate_set_heartbeat_data/2-parameters"},{"type":"function","title":"Returns - DeribitEx.Adapter.generate_set_heartbeat_data/2","doc":"- `{:ok, encoded_request, updated_state}` - The JSON request and updated state","ref":"DeribitEx.Adapter.html#generate_set_heartbeat_data/2-returns"},{"type":"function","title":"DeribitEx.Adapter.generate_unsubscribe_all_data/2","doc":"Generates data for the unsubscribe_all operation.\n\nThis function prepares the JSON-RPC request for the public/unsubscribe_all\nendpoint, which stops all active subscriptions.","ref":"DeribitEx.Adapter.html#generate_unsubscribe_all_data/2"},{"type":"function","title":"Parameters - DeribitEx.Adapter.generate_unsubscribe_all_data/2","doc":"- `params` - Parameters (unused but kept for consistency)\n- `state` - The current adapter state","ref":"DeribitEx.Adapter.html#generate_unsubscribe_all_data/2-parameters"},{"type":"function","title":"Returns - DeribitEx.Adapter.generate_unsubscribe_all_data/2","doc":"- `{:ok, encoded_request, updated_state}` - The JSON request and updated state","ref":"DeribitEx.Adapter.html#generate_unsubscribe_all_data/2-returns"},{"type":"function","title":"DeribitEx.Adapter.generate_unsubscribe_data/2","doc":"Generates data for the unsubscribe operation.\n\nThis function prepares the JSON-RPC request for the public/unsubscribe or private/unsubscribe\nendpoint, which stops the stream for specified channels.","ref":"DeribitEx.Adapter.html#generate_unsubscribe_data/2"},{"type":"function","title":"Parameters - DeribitEx.Adapter.generate_unsubscribe_data/2","doc":"- `params` - Parameters for unsubscribe, includes the channels to unsubscribe from\n- `state` - The current adapter state","ref":"DeribitEx.Adapter.html#generate_unsubscribe_data/2-parameters"},{"type":"function","title":"Returns - DeribitEx.Adapter.generate_unsubscribe_data/2","doc":"- `{:ok, encoded_request, updated_state}` - The JSON request and updated state","ref":"DeribitEx.Adapter.html#generate_unsubscribe_data/2-returns"},{"type":"function","title":"DeribitEx.Adapter.handle_auth_response/2","doc":"Handles authentication response from Deribit.\n\nProcesses different types of responses:\n- Success: Stores token and expiration time\n- Error: Stores error details\n- Other: Passes through\n\nUses WebsockexNova's built-in authentication refresh mechanism to\nhandle token renewal before expiration.","ref":"DeribitEx.Adapter.html#handle_auth_response/2"},{"type":"function","title":"DeribitEx.Adapter.handle_connect/2","doc":"Handles the connection established event.\n\nExecutes telemetry events for connection opening, updates the state, and\nhandles reconnection logic by resetting reconnect_attempts counter.\n\nLeverages WebsockexNova's connection event callbacks to automatically\ntrigger authentication and resubscription after reconnections.","ref":"DeribitEx.Adapter.html#handle_connect/2"},{"type":"function","title":"DeribitEx.Adapter.handle_disable_cod_response/2","doc":"Handles disable_cancel_on_disconnect response from Deribit.\n\nUpdates the state to reflect the COD status after disabling it.","ref":"DeribitEx.Adapter.html#handle_disable_cod_response/2"},{"type":"function","title":"DeribitEx.Adapter.handle_disable_heartbeat_response/2","doc":"Handles disable_heartbeat response from Deribit.\n\nUpdates the state to reflect the heartbeat status after disabling it.","ref":"DeribitEx.Adapter.html#handle_disable_heartbeat_response/2"},{"type":"function","title":"DeribitEx.Adapter.handle_enable_cod_response/2","doc":"Handles enable_cancel_on_disconnect response from Deribit.\n\nUpdates the state to reflect the COD status after enabling it.","ref":"DeribitEx.Adapter.html#handle_enable_cod_response/2"},{"type":"function","title":"DeribitEx.Adapter.handle_exchange_token_response/2","doc":"Handles token exchange response from Deribit.\n\nProcesses response from the public/exchange_token endpoint and updates\nstate with new tokens and expiration information.","ref":"DeribitEx.Adapter.html#handle_exchange_token_response/2"},{"type":"function","title":"DeribitEx.Adapter.handle_fork_token_response/2","doc":"Handles token fork response from Deribit.\n\nProcesses response from the public/fork_token endpoint and updates\nstate with new tokens and expiration information.","ref":"DeribitEx.Adapter.html#handle_fork_token_response/2"},{"type":"function","title":"DeribitEx.Adapter.handle_frame/3","doc":"Handles raw WebSocket frames from the Deribit API.\n\nThis function is called for each incoming WebSocket frame before JSON parsing.\nHandles heartbeat test_request messages directly at the frame level.","ref":"DeribitEx.Adapter.html#handle_frame/3"},{"type":"function","title":"DeribitEx.Adapter.handle_get_cod_response/2","doc":"Handles get_cancel_on_disconnect response from Deribit.\n\nUpdates the state with the current COD status from the API.","ref":"DeribitEx.Adapter.html#handle_get_cod_response/2"},{"type":"function","title":"DeribitEx.Adapter.handle_info/2","doc":"Handles various info messages sent to the process.\n\nThis used to handle manual refresh_auth messages, but now we use \nWebsockexNova's built-in auth refresh mechanism. This handler remains\nfor backward compatibility with existing tests and other potential\ncustom messages.","ref":"DeribitEx.Adapter.html#handle_info/2"},{"type":"function","title":"DeribitEx.Adapter.handle_logout_response/2","doc":"Handles logout response from Deribit.\n\nUpdates the state to reflect the user is no longer authenticated by:\n- Setting auth_status to :unauthenticated\n- Removing access_token, refresh_token, and related fields\n\nThis ensures that after logout, any subsequent operations requiring authentication\nwill require a new authentication process.","ref":"DeribitEx.Adapter.html#handle_logout_response/2"},{"type":"function","title":"Parameters - DeribitEx.Adapter.handle_logout_response/2","doc":"- `response` - The response from Deribit for the logout request\n- `state` - Current adapter state","ref":"DeribitEx.Adapter.html#handle_logout_response/2-parameters"},{"type":"function","title":"Returns - DeribitEx.Adapter.handle_logout_response/2","doc":"- `{:ok, updated_state}` - On successful logout with state cleared of auth data\n- `{:error, error, updated_state}` - On error response, with error recorded in state\n- `{:ok, state}` - For unrecognized responses (fallthrough case)","ref":"DeribitEx.Adapter.html#handle_logout_response/2-returns"},{"type":"function","title":"Examples - DeribitEx.Adapter.handle_logout_response/2","doc":"# Successful logout\n    response = %{\"result\" => \"ok\"}\n    {:ok, updated_state} = handle_logout_response(response, state)\n    # updated_state.auth_status == :unauthenticated\n    \n    # Error response\n    response = %{\"error\" => %{\"code\" => 10011, \"message\" => \"Error message\"}}\n    {:error, error, updated_state} = handle_logout_response(response, state)","ref":"DeribitEx.Adapter.html#handle_logout_response/2-examples"},{"type":"function","title":"DeribitEx.Adapter.handle_message/2","doc":"Handles messages from Deribit WebSocket API.\n\nProcesses different message types:\n- Auth errors: Signals need for authentication\n- JSON-RPC responses: Matches with tracked requests and processes appropriately\n- Other messages: Delegates to DefaultMessageHandler","ref":"DeribitEx.Adapter.html#handle_message/2"},{"type":"function","title":"DeribitEx.Adapter.handle_set_heartbeat_response/2","doc":"Handles set_heartbeat response from Deribit.\n\nUpdates the state to reflect the heartbeat status after enabling it.","ref":"DeribitEx.Adapter.html#handle_set_heartbeat_response/2"},{"type":"function","title":"DeribitEx.Adapter.handle_subscription_response/2","doc":"Handles subscription response from Deribit.","ref":"DeribitEx.Adapter.html#handle_subscription_response/2"},{"type":"function","title":"DeribitEx.Adapter.handle_unsubscribe_all_response/2","doc":"Handles unsubscribe_all response from Deribit.\n\nUpdates the state to clear all subscriptions.","ref":"DeribitEx.Adapter.html#handle_unsubscribe_all_response/2"},{"type":"function","title":"DeribitEx.Adapter.handle_unsubscribe_response/2","doc":"Handles unsubscribe response from Deribit.\n\nUpdates the state to remove the unsubscribed channels.","ref":"DeribitEx.Adapter.html#handle_unsubscribe_response/2"},{"type":"function","title":"DeribitEx.Adapter.init/1","doc":"Initializes the adapter's state.","ref":"DeribitEx.Adapter.html#init/1"},{"type":"function","title":"DeribitEx.Adapter.send_rpc_request/4","doc":"Sends a JSON-RPC request to the Deribit API.\n\nThis is a general-purpose RPC handler for sending any Deribit API request.\nIt handles request generation, authentication, timeout tracking, and more.","ref":"DeribitEx.Adapter.html#send_rpc_request/4"},{"type":"function","title":"Parameters - DeribitEx.Adapter.send_rpc_request/4","doc":"- `method` - The JSON-RPC method to call (e.g., \"public/get_time\")\n- `params` - The parameters to pass to the method (map)\n- `state` - The current adapter state\n- `options` - Optional request options","ref":"DeribitEx.Adapter.html#send_rpc_request/4-parameters"},{"type":"function","title":"Returns - DeribitEx.Adapter.send_rpc_request/4","doc":"- `{:ok, encoded_request, updated_state}` - The JSON request and updated state","ref":"DeribitEx.Adapter.html#send_rpc_request/4-returns"},{"type":"function","title":"DeribitEx.Adapter.subscribe/3","doc":"Creates a subscription request for a specific channel.\n\nHandles different subscription types (public vs. private)\nbased on channel name and authentication status.","ref":"DeribitEx.Adapter.html#subscribe/3"},{"type":"function","title":"DeribitEx.Adapter.terminate/2","doc":"Handles termination of the adapter process.\n\nExecutes telemetry events for connection closing and updates reconnection attempts.\nHandles graceful shutdowns vs. unexpected disconnections.\n\nEnhanced to better integrate with WebsockexNova's connection lifecycle management\nfor intelligent reconnections with authentication preservation.","ref":"DeribitEx.Adapter.html#terminate/2"},{"type":"module","title":"DeribitEx.Client","doc":"User-friendly client interface for interacting with the Deribit WebSocket API.\n\nThis module provides simplified methods for:\n- Connecting and disconnecting\n- Authentication (public/auth, token exchange, token forking, and logout)\n- Utility endpoints (get_time, hello, status, test)\n- Session management (heartbeat, cancel on disconnect)\n- Subscription management for various Deribit channels","ref":"DeribitEx.Client.html"},{"type":"module","title":"Public Utility Endpoints - DeribitEx.Client","doc":"```elixir\n# Sync clocks with the server\n{:ok, timestamp} = Client.get_time(conn)\n\n# Introduce the client to the server\n{:ok, server_info} = Client.hello(conn, \"my_bot\", \"1.0.0\")\n\n# Check system status\n{:ok, status} = Client.status(conn)\n\n# Simple connectivity test\n{:ok, result} = Client.test(conn, \"echo_me\")\n```","ref":"DeribitEx.Client.html#module-public-utility-endpoints"},{"type":"module","title":"Authentication - DeribitEx.Client","doc":"```elixir\n# Authenticate with credentials from environment variables\n{:ok, conn} = Client.authenticate(conn)\n\n# Exchange token for a different subaccount\n{:ok, _} = Client.exchange_token(conn, refresh_token, subject_id)\n\n# Create a named session\n{:ok, _} = Client.fork_token(conn, refresh_token, \"analytics_session\")\n\n# Logout\n{:ok, conn} = Client.logout(conn)\n```","ref":"DeribitEx.Client.html#module-authentication"},{"type":"module","title":"Subscriptions - DeribitEx.Client","doc":"```elixir\n# Subscribe to trades for BTC-PERPETUAL\n{:ok, sub_id} = Client.subscribe_to_trades(conn, \"BTC-PERPETUAL\")\n\n# Subscribe to orderbook with depth=10\n{:ok, sub_id} = Client.subscribe_to_orderbook(conn, \"BTC-PERPETUAL\", \"100ms\", 10)\n```","ref":"DeribitEx.Client.html#module-subscriptions"},{"type":"function","title":"DeribitEx.Client.authenticate/3","doc":"Authenticate with the Deribit API using client credentials.\n\nUses credentials from the environment variables DERIBIT_CLIENT_ID and\nDERIBIT_CLIENT_SECRET if not provided.","ref":"DeribitEx.Client.html#authenticate/3"},{"type":"function","title":"Options - DeribitEx.Client.authenticate/3","doc":"- `:api_key` - Deribit API key (optional if in environment)\n- `:secret` - Deribit API secret (optional if in environment)\n- `opts` - Additional options passed to the authentication request (e.g., timeout settings)","ref":"DeribitEx.Client.html#authenticate/3-options"},{"type":"function","title":"Examples - DeribitEx.Client.authenticate/3","doc":"# Authenticate using environment variables\n    {:ok, conn} = Client.authenticate(conn)\n\n    # Authenticate with explicit credentials\n    {:ok, conn} = Client.authenticate(conn, %{\n      api_key: \"your_api_key\",\n      secret: \"your_secret\"\n    })","ref":"DeribitEx.Client.html#authenticate/3-examples"},{"type":"function","title":"DeribitEx.Client.connect/1","doc":"Connect to the Deribit WebSocket API.\n\nUses environment-specific endpoints (test.deribit.com for dev/test,\nwww.deribit.com for production) unless overridden.","ref":"DeribitEx.Client.html#connect/1"},{"type":"function","title":"Options - DeribitEx.Client.connect/1","doc":"All WebsockexNova.Client options are supported, plus:\n- `:host` - Override the default host (optional)\n- `:callback_pid` - Process to receive WebSocket events (optional)\n- `:auth_refresh_threshold` - Seconds before token expiration to refresh (defaults to 180s)\n  - Deribit tokens usually last 900 seconds (15 minutes)\n  - Recommended refresh threshold is 180-300 seconds before expiration\n  - Can also be set via DERIBIT_AUTH_REFRESH_THRESHOLD environment variable\n  - Valid range: 1-899 seconds\n  - Smaller values risk token expiration during high latency periods\n  - Larger values cause more frequent token refreshes\n  - Value of 180s balances reliability with refresh frequency\n- `:rate_limit_mode` - Rate limiting strategy (defaults to :normal)\n  - `:cautious` - Strict limits to avoid 429s completely (60 req/sec)\n  - `:normal` - Balanced approach (120 req/sec)\n  - `:aggressive` - Higher throughput (200 req/sec), might get occasional 429s\n  - Can also be set via DERIBIT_RATE_LIMIT_MODE environment variable","ref":"DeribitEx.Client.html#connect/1-options"},{"type":"function","title":"Rate Limiting Behavior - DeribitEx.Client.connect/1","doc":"The connection uses a custom adaptive rate limiter that:\n- Adjusts rate limits dynamically based on Deribit API responses\n- Implements exponential backoff when 429 responses are received\n- Prioritizes critical operations like order cancellation\n- Gradually recovers request rates after backoff periods\n- Emits detailed telemetry for monitoring rate limiting behavior","ref":"DeribitEx.Client.html#connect/1-rate-limiting-behavior"},{"type":"function","title":"Examples - DeribitEx.Client.connect/1","doc":"# Connect with default options\n    {:ok, conn} = Client.connect()\n\n    # Connect with custom host\n    {:ok, conn} = Client.connect(%{host: \"custom.deribit.com\"})\n\n    # Connect with callback process\n    {:ok, conn} = Client.connect(%{callback_pid: self()})\n\n    # Connect with custom auth refresh threshold (5 minutes)\n    {:ok, conn} = Client.connect(%{auth_refresh_threshold: 300})\n\n    # Connect with cautious rate limiting\n    {:ok, conn} = Client.connect(%{rate_limit_mode: :cautious})","ref":"DeribitEx.Client.html#connect/1-examples"},{"type":"function","title":"DeribitEx.Client.current_server_time/1","doc":"Get the current server time from the TimeSyncService without making a request.\n\nThis function returns the estimated server time based on the local time and the\ntime delta maintained by the TimeSyncService. It is useful when you need to know\nthe server time without making an additional request to the server.","ref":"DeribitEx.Client.html#current_server_time/1"},{"type":"function","title":"Parameters - DeribitEx.Client.current_server_time/1","doc":"* `conn` - Connection process PID","ref":"DeribitEx.Client.html#current_server_time/1-parameters"},{"type":"function","title":"Returns - DeribitEx.Client.current_server_time/1","doc":"* `{:ok, server_time_ms}` - The current server time in milliseconds\n  * `{:error, :no_time_sync}` - If time sync service is not running for this connection","ref":"DeribitEx.Client.html#current_server_time/1-returns"},{"type":"function","title":"Examples - DeribitEx.Client.current_server_time/1","doc":"# Get the current estimated server time\n    {:ok, server_time} = Client.current_server_time(conn)","ref":"DeribitEx.Client.html#current_server_time/1-examples"},{"type":"function","title":"DeribitEx.Client.disable_cancel_on_disconnect/3","doc":"Disable Cancel on Disconnect (COD) for the specified scope.","ref":"DeribitEx.Client.html#disable_cancel_on_disconnect/3"},{"type":"function","title":"Parameters - DeribitEx.Client.disable_cancel_on_disconnect/3","doc":"- `conn` - Connection process PID\n- `scope` - Scope of the COD setting (\"connection\" or \"account\", defaults to \"connection\")\n- `opts` - Optional request options","ref":"DeribitEx.Client.html#disable_cancel_on_disconnect/3-parameters"},{"type":"function","title":"Returns - DeribitEx.Client.disable_cancel_on_disconnect/3","doc":"- `{:ok, \"ok\"}` - Success response indicating COD is disabled\n- `{:error, reason}` - If the request fails","ref":"DeribitEx.Client.html#disable_cancel_on_disconnect/3-returns"},{"type":"function","title":"Examples - DeribitEx.Client.disable_cancel_on_disconnect/3","doc":"# Disable COD for current connection\n    {:ok, _} = Client.disable_cancel_on_disconnect(conn)\n\n    # Disable COD for the entire account\n    {:ok, _} = Client.disable_cancel_on_disconnect(conn, \"account\")","ref":"DeribitEx.Client.html#disable_cancel_on_disconnect/3-examples"},{"type":"function","title":"DeribitEx.Client.disable_heartbeat/2","doc":"Disable heartbeat messages from the Deribit server.","ref":"DeribitEx.Client.html#disable_heartbeat/2"},{"type":"function","title":"Parameters - DeribitEx.Client.disable_heartbeat/2","doc":"- `conn` - Connection process PID\n- `opts` - Optional request options","ref":"DeribitEx.Client.html#disable_heartbeat/2-parameters"},{"type":"function","title":"Returns - DeribitEx.Client.disable_heartbeat/2","doc":"- `{:ok, \"ok\"}` - Success response indicating heartbeat is disabled\n- `{:error, reason}` - If the request fails","ref":"DeribitEx.Client.html#disable_heartbeat/2-returns"},{"type":"function","title":"Examples - DeribitEx.Client.disable_heartbeat/2","doc":"# Disable heartbeat\n    {:ok, _} = Client.disable_heartbeat(conn)","ref":"DeribitEx.Client.html#disable_heartbeat/2-examples"},{"type":"function","title":"DeribitEx.Client.disconnect/2","doc":"Close the WebSocket connection to the Deribit API.","ref":"DeribitEx.Client.html#disconnect/2"},{"type":"function","title":"Parameters - DeribitEx.Client.disconnect/2","doc":"- `conn` - Connection process PID\n- `reason` - Reason for disconnection (optional)","ref":"DeribitEx.Client.html#disconnect/2-parameters"},{"type":"function","title":"Examples - DeribitEx.Client.disconnect/2","doc":"# Close with normal reason\n    :ok = Client.disconnect(conn)\n\n    # Close with custom reason\n    :ok = Client.disconnect(conn, :shutdown)","ref":"DeribitEx.Client.html#disconnect/2-examples"},{"type":"function","title":"DeribitEx.Client.enable_cancel_on_disconnect/3","doc":"Enable Cancel on Disconnect (COD) for the current session.\n\nWhen enabled, all orders created during the connection will be automatically\ncancelled if the connection is closed or interrupted. This is a safety feature\nto prevent orphaned orders in case of connection issues.","ref":"DeribitEx.Client.html#enable_cancel_on_disconnect/3"},{"type":"function","title":"Parameters - DeribitEx.Client.enable_cancel_on_disconnect/3","doc":"- `conn` - Connection process PID\n- `scope` - Scope of the COD setting (\"connection\" or \"account\", defaults to \"connection\")\n- `opts` - Optional request options","ref":"DeribitEx.Client.html#enable_cancel_on_disconnect/3-parameters"},{"type":"function","title":"Returns - DeribitEx.Client.enable_cancel_on_disconnect/3","doc":"- `{:ok, \"ok\"}` - Success response indicating COD is enabled\n- `{:error, reason}` - If the request fails","ref":"DeribitEx.Client.html#enable_cancel_on_disconnect/3-returns"},{"type":"function","title":"Examples - DeribitEx.Client.enable_cancel_on_disconnect/3","doc":"# Enable COD for current connection only\n    {:ok, _} = Client.enable_cancel_on_disconnect(conn)\n\n    # Enable COD for the entire account\n    {:ok, _} = Client.enable_cancel_on_disconnect(conn, \"account\")","ref":"DeribitEx.Client.html#enable_cancel_on_disconnect/3-examples"},{"type":"function","title":"DeribitEx.Client.exchange_token/4","doc":"Generate a new access token for switching between subaccounts.\n\nUses the refresh token to create a new authentication session for a different subject ID.","ref":"DeribitEx.Client.html#exchange_token/4"},{"type":"function","title":"Parameters - DeribitEx.Client.exchange_token/4","doc":"- `conn` - Connection process PID\n- `refresh_token` - Valid refresh token (optional, uses stored token if available)\n- `subject_id` - ID of the subaccount to switch to\n- `opts` - Additional options for the request (optional)","ref":"DeribitEx.Client.html#exchange_token/4-parameters"},{"type":"function","title":"Examples - DeribitEx.Client.exchange_token/4","doc":"# Exchange token to switch to subaccount with ID 10\n    {:ok, response} = Client.exchange_token(conn, \"refresh_token_value\", 10)\n\n    # Exchange token using a stored refresh token\n    {:ok, response} = Client.exchange_token(conn, nil, 10)","ref":"DeribitEx.Client.html#exchange_token/4-examples"},{"type":"function","title":"DeribitEx.Client.fork_token/4","doc":"Generate a token for a new named session.\n\nUses the refresh token to create a new authentication session with the specified name.","ref":"DeribitEx.Client.html#fork_token/4"},{"type":"function","title":"Parameters - DeribitEx.Client.fork_token/4","doc":"- `conn` - Connection process PID\n- `refresh_token` - Valid refresh token (optional, uses stored token if available)\n- `session_name` - Name for the new session\n- `opts` - Additional options for the request (optional)","ref":"DeribitEx.Client.html#fork_token/4-parameters"},{"type":"function","title":"Examples - DeribitEx.Client.fork_token/4","doc":"# Fork token to create a new named session\n    {:ok, response} = Client.fork_token(conn, \"refresh_token_value\", \"trading_session\")\n\n    # Fork token using a stored refresh token\n    {:ok, response} = Client.fork_token(conn, nil, \"analytics_session\")","ref":"DeribitEx.Client.html#fork_token/4-examples"},{"type":"function","title":"DeribitEx.Client.get_cancel_on_disconnect/2","doc":"Get the current Cancel on Disconnect (COD) configuration.","ref":"DeribitEx.Client.html#get_cancel_on_disconnect/2"},{"type":"function","title":"Parameters - DeribitEx.Client.get_cancel_on_disconnect/2","doc":"- `conn` - Connection process PID\n- `opts` - Optional request options","ref":"DeribitEx.Client.html#get_cancel_on_disconnect/2-parameters"},{"type":"function","title":"Returns - DeribitEx.Client.get_cancel_on_disconnect/2","doc":"- `{:ok, %{\"scope\" => scope, \"enabled\" => enabled}}` - The current COD configuration\n- `{:error, reason}` - If the request fails","ref":"DeribitEx.Client.html#get_cancel_on_disconnect/2-returns"},{"type":"function","title":"Examples - DeribitEx.Client.get_cancel_on_disconnect/2","doc":"# Check if COD is enabled for the connection\n    {:ok, %{\"enabled\" => true, \"scope\" => \"connection\"}} = Client.get_cancel_on_disconnect(conn)","ref":"DeribitEx.Client.html#get_cancel_on_disconnect/2-examples"},{"type":"function","title":"DeribitEx.Client.get_time/2","doc":"Fetch Deribit's current server time (ms since epoch).","ref":"DeribitEx.Client.html#get_time/2"},{"type":"function","title":"Parameters - DeribitEx.Client.get_time/2","doc":"- `conn` – the WebSocket client PID\n- `opts` – optional JSON-RPC options","ref":"DeribitEx.Client.html#get_time/2-parameters"},{"type":"function","title":"Returns - DeribitEx.Client.get_time/2","doc":"- `{:ok, timestamp}` on success\n- `{:error, reason}` on failure","ref":"DeribitEx.Client.html#get_time/2-returns"},{"type":"function","title":"DeribitEx.Client.hello/4","doc":"Send a hello message to introduce the client to Deribit.\n\nUsed to identify the client to the server and establish the initial session.","ref":"DeribitEx.Client.html#hello/4"},{"type":"function","title":"Parameters - DeribitEx.Client.hello/4","doc":"- `conn` - Connection process PID\n- `client_name` - The name of the client (defaults to \"market_maker\")\n- `client_version` - The version of the client (defaults to \"1.0.0\")\n- `opts` - Optional request options","ref":"DeribitEx.Client.html#hello/4-parameters"},{"type":"function","title":"Returns - DeribitEx.Client.hello/4","doc":"- `{:ok, result}` - Success response with server version\n- `{:error, reason}` - If the request fails","ref":"DeribitEx.Client.html#hello/4-returns"},{"type":"function","title":"Examples - DeribitEx.Client.hello/4","doc":"# Send hello with default client info\n    {:ok, server_info} = Client.hello(conn)\n\n    # Send hello with custom client info\n    {:ok, server_info} = Client.hello(conn, \"my_trading_bot\", \"2.1.0\")","ref":"DeribitEx.Client.html#hello/4-examples"},{"type":"function","title":"DeribitEx.Client.initialize/2","doc":"Initialize the Deribit connection with a bootstrap sequence.\n\nAfter connecting to Deribit via WebSocket, this function performs a bootstrap\nsequence to properly initialize the session:\n\n1. `/public/hello` to introduce client name & version\n2. `/public/get_time` to sync clocks\n3. `/public/status` to check account status\n4. `/public/set_heartbeat` to enable heartbeats (minimum 10s)\n5. `/private/enable_cancel_on_disconnect` with default scope for COD safety\n   (requires authentication first)\n\nThe adapter is also set up to automatically handle incoming `test_request`\nmessages by responding with `/public/test`.","ref":"DeribitEx.Client.html#initialize/2"},{"type":"function","title":"Parameters - DeribitEx.Client.initialize/2","doc":"- `conn` - Connection process PID\n- `opts` - Optional bootstrap configuration:\n  - `:client_name` - Custom client name (defaults to \"market_maker\")\n  - `:client_version` - Custom client version (defaults to \"1.0.0\")\n  - `:heartbeat_interval` - Heartbeat interval in seconds (defaults to 30, minimum 10)\n  - `:cod_scope` - Scope for cancel-on-disconnect (defaults to \"connection\")\n  - `:authenticate` - Whether to authenticate before other steps (defaults to true)","ref":"DeribitEx.Client.html#initialize/2-parameters"},{"type":"function","title":"Returns - DeribitEx.Client.initialize/2","doc":"- `{:ok, bootstrap_results}` - Success with a map of all bootstrap operation results\n- `{:error, step, reason}` - First failed operation with the reason","ref":"DeribitEx.Client.html#initialize/2-returns"},{"type":"function","title":"Examples - DeribitEx.Client.initialize/2","doc":"# Initialize with default settings\n    {:ok, results} = Client.initialize(conn)\n\n    # Custom initialization\n    {:ok, results} = Client.initialize(conn, %{\n      client_name: \"trading_bot\",\n      client_version: \"2.0.0\",\n      heartbeat_interval: 15,\n      cod_scope: \"account\"\n    })\n\n    # Skip authentication\n    {:ok, results} = Client.initialize(conn, %{authenticate: false})","ref":"DeribitEx.Client.html#initialize/2-examples"},{"type":"function","title":"DeribitEx.Client.json_rpc/4","doc":"Send a custom JSON-RPC request to the Deribit API.","ref":"DeribitEx.Client.html#json_rpc/4"},{"type":"function","title":"Parameters - DeribitEx.Client.json_rpc/4","doc":"- `conn` - Connection process PID\n- `method` - RPC method name (e.g., \"public/get_instruments\")\n- `params` - Method parameters (map)\n- `opts` - Optional request options","ref":"DeribitEx.Client.html#json_rpc/4-parameters"},{"type":"function","title":"Examples - DeribitEx.Client.json_rpc/4","doc":"# Get available instruments for BTC\n    {:ok, response} = Client.json_rpc(conn, \"public/get_instruments\", %{\n      currency: \"BTC\",\n      kind: \"future\"\n    })","ref":"DeribitEx.Client.html#json_rpc/4-examples"},{"type":"function","title":"DeribitEx.Client.logout/3","doc":"Logout and optionally invalidate tokens.\n\nGracefully closes the session with the Deribit API and optionally\ninvalidates all tokens created in the current session. This is important\nfor secure session management.\n\nThis function:\n1. Sends the private/logout RPC request\n2. Cleans up authentication state in the adapter\n3. Automatically closes the WebSocket connection afterwards\n\nThe invalidate_token parameter determines whether to invalidate all tokens:\n- When set to true (default), all access and refresh tokens become invalid\n- When set to false, tokens remain valid but the current session ends","ref":"DeribitEx.Client.html#logout/3"},{"type":"function","title":"Parameters - DeribitEx.Client.logout/3","doc":"- `conn` - Connection process PID\n- `invalidate_token` - Whether to invalidate all tokens (default: true)\n- `opts` - Additional options for the request (optional):\n  - `:timeout` - Request timeout in milliseconds (default: 10000)","ref":"DeribitEx.Client.html#logout/3-parameters"},{"type":"function","title":"Returns - DeribitEx.Client.logout/3","doc":"- `{:ok, conn}` - On successful logout, even though the connection is closed\n- `{:error, reason}` - If the logout request fails","ref":"DeribitEx.Client.html#logout/3-returns"},{"type":"function","title":"Notes - DeribitEx.Client.logout/3","doc":"- The WebSocket connection is automatically closed after logout\n- The adapter state is updated to remove authentication data\n- In high-latency environments, the request may timeout","ref":"DeribitEx.Client.html#logout/3-notes"},{"type":"function","title":"Examples - DeribitEx.Client.logout/3","doc":"# Logout and invalidate all tokens\n    {:ok, conn} = Client.logout(conn)\n\n    # Logout without invalidating tokens\n    {:ok, conn} = Client.logout(conn, false)\n    \n    # Logout with custom timeout\n    {:ok, conn} = Client.logout(conn, true, %{timeout: 30000})","ref":"DeribitEx.Client.html#logout/3-examples"},{"type":"function","title":"DeribitEx.Client.parse_response/1","doc":"Parse a JSON-RPC response and extract the result or error.\n\nThis helper function provides consistent handling of JSON-RPC responses,\nextracting the relevant result or error from the response envelope.","ref":"DeribitEx.Client.html#parse_response/1"},{"type":"function","title":"Parameters - DeribitEx.Client.parse_response/1","doc":"- `response` - The raw response from a JSON-RPC call","ref":"DeribitEx.Client.html#parse_response/1-parameters"},{"type":"function","title":"Returns - DeribitEx.Client.parse_response/1","doc":"- `{:ok, result}` - On successful responses\n- `{:error, error}` - On error responses","ref":"DeribitEx.Client.html#parse_response/1-returns"},{"type":"function","title":"Examples - DeribitEx.Client.parse_response/1","doc":"iex> Client.parse_response(%{\"jsonrpc\" => \"2.0\", \"id\" => 1, \"result\" => 123})\n    {:ok, 123}\n\n    iex> Client.parse_response(%{\"jsonrpc\" => \"2.0\", \"id\" => 1, \"error\" => %{\"code\" => 10001, \"message\" => \"Error\"}})\n    {:error, %{\"code\" => 10001, \"message\" => \"Error\"}}","ref":"DeribitEx.Client.html#parse_response/1-examples"},{"type":"function","title":"DeribitEx.Client.set_heartbeat/3","doc":"Enable heartbeat messages from the Deribit server.\n\nHeartbeats are used to detect stale connections. When enabled, the server will send\ntest_request messages periodically, and the adapter will automatically respond to them.","ref":"DeribitEx.Client.html#set_heartbeat/3"},{"type":"function","title":"Parameters - DeribitEx.Client.set_heartbeat/3","doc":"- `conn` - Connection process PID\n- `interval` - Heartbeat interval in seconds (min: 10, defaults to 30)\n- `opts` - Optional request options","ref":"DeribitEx.Client.html#set_heartbeat/3-parameters"},{"type":"function","title":"Returns - DeribitEx.Client.set_heartbeat/3","doc":"- `{:ok, \"ok\"}` - Success response indicating heartbeat is enabled\n- `{:error, reason}` - If the request fails","ref":"DeribitEx.Client.html#set_heartbeat/3-returns"},{"type":"function","title":"Examples - DeribitEx.Client.set_heartbeat/3","doc":"# Enable heartbeat with default 30 second interval\n    {:ok, _} = Client.set_heartbeat(conn)\n\n    # Enable heartbeat with custom interval\n    {:ok, _} = Client.set_heartbeat(conn, 15)","ref":"DeribitEx.Client.html#set_heartbeat/3-examples"},{"type":"function","title":"DeribitEx.Client.status/2","doc":"Get the system status from Deribit.\n\nReturns information about the status of the API, including any service\ndisruptions, scheduled maintenance, or important announcements.","ref":"DeribitEx.Client.html#status/2"},{"type":"function","title":"Parameters - DeribitEx.Client.status/2","doc":"- `conn` - Connection process PID\n- `opts` - Optional request options","ref":"DeribitEx.Client.html#status/2-parameters"},{"type":"function","title":"Returns - DeribitEx.Client.status/2","doc":"- `{:ok, status}` - The system status information\n- `{:error, reason}` - If the request fails","ref":"DeribitEx.Client.html#status/2-returns"},{"type":"function","title":"Examples - DeribitEx.Client.status/2","doc":"# Check if the system is operational\n    {:ok, status} = Client.status(conn)\n\n    # Handle possible maintenance mode\n    case Client.status(conn) do\n      {:ok, %{\"status\" => \"ok\"}} -> # System is operational\n      {:ok, %{\"status\" => \"maintenance\"}} -> # System is in maintenance mode\n      {:error, reason} -> # Request failed\n    end","ref":"DeribitEx.Client.html#status/2-examples"},{"type":"function","title":"DeribitEx.Client.subscribe_to_orderbook/5","doc":"Subscribe to a Deribit orderbook channel for a specific instrument.","ref":"DeribitEx.Client.html#subscribe_to_orderbook/5"},{"type":"function","title":"Parameters - DeribitEx.Client.subscribe_to_orderbook/5","doc":"- `conn` - Connection process PID\n- `instrument` - Instrument name (e.g., \"BTC-PERPETUAL\")\n- `interval` - Update interval (optional, e.g., \"100ms\", \"raw\")\n- `depth` - Orderbook depth (optional, default is full orderbook)","ref":"DeribitEx.Client.html#subscribe_to_orderbook/5-parameters"},{"type":"function","title":"Example - DeribitEx.Client.subscribe_to_orderbook/5","doc":"{:ok, sub_id} = Client.subscribe_to_orderbook(conn, \"BTC-PERPETUAL\", \"100ms\", 10)","ref":"DeribitEx.Client.html#subscribe_to_orderbook/5-example"},{"type":"function","title":"DeribitEx.Client.subscribe_to_ticker/4","doc":"Subscribe to a Deribit ticker channel for a specific instrument.","ref":"DeribitEx.Client.html#subscribe_to_ticker/4"},{"type":"function","title":"Parameters - DeribitEx.Client.subscribe_to_ticker/4","doc":"- `conn` - Connection process PID\n- `instrument` - Instrument name (e.g., \"BTC-PERPETUAL\")\n- `interval` - Update interval (optional, e.g., \"100ms\", \"raw\")","ref":"DeribitEx.Client.html#subscribe_to_ticker/4-parameters"},{"type":"function","title":"Example - DeribitEx.Client.subscribe_to_ticker/4","doc":"{:ok, sub_id} = Client.subscribe_to_ticker(conn, \"BTC-PERPETUAL\", \"100ms\")","ref":"DeribitEx.Client.html#subscribe_to_ticker/4-example"},{"type":"function","title":"DeribitEx.Client.subscribe_to_trades/4","doc":"Subscribe to a Deribit trades channel for a specific instrument.","ref":"DeribitEx.Client.html#subscribe_to_trades/4"},{"type":"function","title":"Parameters - DeribitEx.Client.subscribe_to_trades/4","doc":"- `conn` - Connection process PID\n- `instrument` - Instrument name (e.g., \"BTC-PERPETUAL\")\n- `interval` - Update interval (optional, e.g., \"100ms\", \"raw\")","ref":"DeribitEx.Client.html#subscribe_to_trades/4-parameters"},{"type":"function","title":"Example - DeribitEx.Client.subscribe_to_trades/4","doc":"{:ok, sub_id} = Client.subscribe_to_trades(conn, \"BTC-PERPETUAL\", \"100ms\")","ref":"DeribitEx.Client.html#subscribe_to_trades/4-example"},{"type":"function","title":"DeribitEx.Client.subscribe_to_user_orders/4","doc":"Subscribe to user's orders for a specific instrument.\nRequires authentication.","ref":"DeribitEx.Client.html#subscribe_to_user_orders/4"},{"type":"function","title":"Parameters - DeribitEx.Client.subscribe_to_user_orders/4","doc":"- `conn` - Connection process PID\n- `instrument` - Instrument name (e.g., \"BTC-PERPETUAL\")\n- `interval` - Update interval (optional, defaults to \"raw\")","ref":"DeribitEx.Client.html#subscribe_to_user_orders/4-parameters"},{"type":"function","title":"Example - DeribitEx.Client.subscribe_to_user_orders/4","doc":"{:ok, sub_id} = Client.subscribe_to_user_orders(conn, \"BTC-PERPETUAL\")","ref":"DeribitEx.Client.html#subscribe_to_user_orders/4-example"},{"type":"function","title":"DeribitEx.Client.subscribe_to_user_trades/4","doc":"Subscribe to user's trades for a specific instrument.\nRequires authentication.","ref":"DeribitEx.Client.html#subscribe_to_user_trades/4"},{"type":"function","title":"Parameters - DeribitEx.Client.subscribe_to_user_trades/4","doc":"- `conn` - Connection process PID\n- `instrument` - Instrument name (e.g., \"BTC-PERPETUAL\")\n- `interval` - Update interval (optional, defaults to \"raw\")","ref":"DeribitEx.Client.html#subscribe_to_user_trades/4-parameters"},{"type":"function","title":"Example - DeribitEx.Client.subscribe_to_user_trades/4","doc":"{:ok, sub_id} = Client.subscribe_to_user_trades(conn, \"BTC-PERPETUAL\")","ref":"DeribitEx.Client.html#subscribe_to_user_trades/4-example"},{"type":"function","title":"DeribitEx.Client.test/3","doc":"Send a test request to Deribit.\n\nThis endpoint is primarily used to respond to test_request messages sent by the server\nas part of the heartbeat mechanism. It can also be used as a simple connectivity check.","ref":"DeribitEx.Client.html#test/3"},{"type":"function","title":"Parameters - DeribitEx.Client.test/3","doc":"- `conn` - Connection process PID\n- `expected_result` - The expected result to be echoed back (optional)\n- `opts` - Optional request options","ref":"DeribitEx.Client.html#test/3-parameters"},{"type":"function","title":"Returns - DeribitEx.Client.test/3","doc":"- `{:ok, result}` - Success response, echoing back the expected_result if provided\n- `{:error, reason}` - If the request fails","ref":"DeribitEx.Client.html#test/3-returns"},{"type":"function","title":"Examples - DeribitEx.Client.test/3","doc":"# Simple connectivity test\n    {:ok, _} = Client.test(conn)\n\n    # Test with expected result echo\n    {:ok, \"hello\"} = Client.test(conn, \"hello\")","ref":"DeribitEx.Client.html#test/3-examples"},{"type":"function","title":"DeribitEx.Client.unsubscribe/3","doc":"Unsubscribe from specific channels.","ref":"DeribitEx.Client.html#unsubscribe/3"},{"type":"function","title":"Parameters - DeribitEx.Client.unsubscribe/3","doc":"- `conn` - Connection process PID\n- `channels` - Single channel string or list of channels to unsubscribe from\n- `opts` - Optional request options","ref":"DeribitEx.Client.html#unsubscribe/3-parameters"},{"type":"function","title":"Returns - DeribitEx.Client.unsubscribe/3","doc":"- `{:ok, result}` - Success response with list of unsubscribed channels\n- `{:error, reason}` - If the request fails","ref":"DeribitEx.Client.html#unsubscribe/3-returns"},{"type":"function","title":"Examples - DeribitEx.Client.unsubscribe/3","doc":"# Unsubscribe from a trades channel\n    {:ok, _} = Client.unsubscribe(conn, \"trades.BTC-PERPETUAL.100ms\")\n\n    # Unsubscribe from multiple channels at once\n    {:ok, _} = Client.unsubscribe(conn, [\n      \"trades.BTC-PERPETUAL.100ms\",\n      \"ticker.BTC-PERPETUAL.raw\"\n    ])","ref":"DeribitEx.Client.html#unsubscribe/3-examples"},{"type":"function","title":"DeribitEx.Client.unsubscribe_all/2","doc":"Unsubscribe from all channels.","ref":"DeribitEx.Client.html#unsubscribe_all/2"},{"type":"function","title":"Parameters - DeribitEx.Client.unsubscribe_all/2","doc":"- `conn` - Connection process PID\n- `opts` - Optional request options","ref":"DeribitEx.Client.html#unsubscribe_all/2-parameters"},{"type":"function","title":"Returns - DeribitEx.Client.unsubscribe_all/2","doc":"- `{:ok, \"ok\"}` - Success response\n- `{:error, reason}` - If the request fails","ref":"DeribitEx.Client.html#unsubscribe_all/2-returns"},{"type":"function","title":"Examples - DeribitEx.Client.unsubscribe_all/2","doc":"# Unsubscribe from all active channels\n    {:ok, _} = Client.unsubscribe_all(conn)","ref":"DeribitEx.Client.html#unsubscribe_all/2-examples"},{"type":"function","title":"DeribitEx.Client.unsubscribe_private/3","doc":"Unsubscribe from private channels.\n\nA convenience function that ensures the private/unsubscribe method is used,\nwhich is required for channels that need authentication.","ref":"DeribitEx.Client.html#unsubscribe_private/3"},{"type":"function","title":"Parameters - DeribitEx.Client.unsubscribe_private/3","doc":"- `conn` - Connection process PID\n- `channels` - Single channel string or list of channels to unsubscribe from\n- `opts` - Optional request options","ref":"DeribitEx.Client.html#unsubscribe_private/3-parameters"},{"type":"function","title":"Returns - DeribitEx.Client.unsubscribe_private/3","doc":"- `{:ok, result}` - Success response with list of unsubscribed channels\n- `{:error, reason}` - If the request fails","ref":"DeribitEx.Client.html#unsubscribe_private/3-returns"},{"type":"function","title":"Examples - DeribitEx.Client.unsubscribe_private/3","doc":"# Unsubscribe from a user orders channel\n    {:ok, _} = Client.unsubscribe_private(conn, \"user.orders.BTC-PERPETUAL.raw\")\n\n    # Unsubscribe from multiple private channels\n    {:ok, _} = Client.unsubscribe_private(conn, [\n      \"user.orders.BTC-PERPETUAL.raw\",\n      \"user.trades.BTC-PERPETUAL.raw\"\n    ])","ref":"DeribitEx.Client.html#unsubscribe_private/3-examples"},{"type":"module","title":"DeribitEx.RPC","doc":"Core JSON-RPC handling for Deribit WebSocket API.\n\nThis module provides infrastructure for:\n- Generating standard JSON-RPC requests\n- Parsing JSON-RPC responses\n- Handling error responses consistently\n- Tracking request IDs\n- Managing timeouts and retries\n- Extracting metadata from responses\n\nThis module is used by the Adapter and Client to\nensure consistent RPC handling and error management.","ref":"DeribitEx.RPC.html"},{"type":"function","title":"DeribitEx.RPC.add_auth_params/3","doc":"Adds authentication token to parameters if required.","ref":"DeribitEx.RPC.html#add_auth_params/3"},{"type":"function","title":"Parameters - DeribitEx.RPC.add_auth_params/3","doc":"- `params` - The original parameters map\n- `method` - The JSON-RPC method string\n- `access_token` - The current access token (or nil if not authenticated)","ref":"DeribitEx.RPC.html#add_auth_params/3-parameters"},{"type":"function","title":"Returns - DeribitEx.RPC.add_auth_params/3","doc":"- Updated parameters map with access_token if required\n- Original parameters map if not required or token not available","ref":"DeribitEx.RPC.html#add_auth_params/3-returns"},{"type":"function","title":"Examples - DeribitEx.RPC.add_auth_params/3","doc":"iex> RPC.add_auth_params(%{}, \"private/get_position\", \"token123\")\n    %{\"access_token\" => \"token123\"}\n    \n    iex> RPC.add_auth_params(%{instrument: \"BTC-PERPETUAL\"}, \"public/get_time\", \"token123\")\n    %{instrument: \"BTC-PERPETUAL\"}","ref":"DeribitEx.RPC.html#add_auth_params/3-examples"},{"type":"function","title":"DeribitEx.RPC.classify_error/1","doc":"Classifies an error based on its error code.","ref":"DeribitEx.RPC.html#classify_error/1"},{"type":"function","title":"Parameters - DeribitEx.RPC.classify_error/1","doc":"- `error` - The error map from the response","ref":"DeribitEx.RPC.html#classify_error/1-parameters"},{"type":"function","title":"Returns - DeribitEx.RPC.classify_error/1","doc":"- `{category, reason, message}` tuple with error classification\n- `:unknown` for unrecognized error codes","ref":"DeribitEx.RPC.html#classify_error/1-returns"},{"type":"function","title":"Examples - DeribitEx.RPC.classify_error/1","doc":"iex> RPC.classify_error(%{\"code\" => 13010, \"message\" => \"Token expired\"})\n    {:auth, :token_expired, \"Token expired\"}\n    \n    iex> RPC.classify_error(%{\"code\" => 99999, \"message\" => \"Unknown error\"})\n    {:unknown, :unknown_code, \"Unknown error\"}","ref":"DeribitEx.RPC.html#classify_error/1-examples"},{"type":"function","title":"DeribitEx.RPC.error/2","doc":"Generates a standardized error tuple for failed Deribit API operations.","ref":"DeribitEx.RPC.html#error/2"},{"type":"function","title":"Parameters - DeribitEx.RPC.error/2","doc":"- `reason` - The error reason\n- `details` - Additional error details","ref":"DeribitEx.RPC.html#error/2-parameters"},{"type":"function","title":"Returns - DeribitEx.RPC.error/2","doc":"- `{:error, map()}` with standardized error structure","ref":"DeribitEx.RPC.html#error/2-returns"},{"type":"function","title":"DeribitEx.RPC.extract_metadata/1","doc":"Extracts response metadata from a JSON-RPC response.\n\nThis is useful for handling data from notification responses like subscriptions.","ref":"DeribitEx.RPC.html#extract_metadata/1"},{"type":"function","title":"Parameters - DeribitEx.RPC.extract_metadata/1","doc":"- `response` - The JSON-RPC response or notification (map)","ref":"DeribitEx.RPC.html#extract_metadata/1-parameters"},{"type":"function","title":"Returns - DeribitEx.RPC.extract_metadata/1","doc":"- Map with extracted metadata (if any)\n- Empty map if no metadata is found","ref":"DeribitEx.RPC.html#extract_metadata/1-returns"},{"type":"function","title":"Examples - DeribitEx.RPC.extract_metadata/1","doc":"iex> RPC.extract_metadata(%{\"jsonrpc\" => \"2.0\", \"method\" => \"subscription\", \"params\" => %{\"channel\" => \"trades.BTC-PERPETUAL.raw\"}})\n    %{channel: \"trades.BTC-PERPETUAL.raw\", type: :subscription}","ref":"DeribitEx.RPC.html#extract_metadata/1-examples"},{"type":"function","title":"DeribitEx.RPC.generate_request/3","doc":"Generates a standard JSON-RPC 2.0 request payload.","ref":"DeribitEx.RPC.html#generate_request/3"},{"type":"function","title":"Parameters - DeribitEx.RPC.generate_request/3","doc":"- `method` - The JSON-RPC method to call (e.g., \"public/auth\")\n- `params` - The parameters to pass to the method (map)\n- `id` - Optional request ID (defaults to a unique integer)","ref":"DeribitEx.RPC.html#generate_request/3-parameters"},{"type":"function","title":"Returns - DeribitEx.RPC.generate_request/3","doc":"- `{:ok, request_payload, request_id}` - The JSON-RPC request and its ID","ref":"DeribitEx.RPC.html#generate_request/3-returns"},{"type":"function","title":"Examples - DeribitEx.RPC.generate_request/3","doc":"iex> RPC.generate_request(\"public/get_time\", %{})\n    {:ok, %{\"jsonrpc\" => \"2.0\", \"id\" => 123, \"method\" => \"public/get_time\", \"params\" => %{}}, 123}","ref":"DeribitEx.RPC.html#generate_request/3-examples"},{"type":"function","title":"DeribitEx.RPC.generate_timeout_reference/1","doc":"Creates a reference for the timeout process that will be canceled when the request is completed.","ref":"DeribitEx.RPC.html#generate_timeout_reference/1"},{"type":"function","title":"Parameters - DeribitEx.RPC.generate_timeout_reference/1","doc":"- `request_id` - The JSON-RPC request ID","ref":"DeribitEx.RPC.html#generate_timeout_reference/1-parameters"},{"type":"function","title":"Returns - DeribitEx.RPC.generate_timeout_reference/1","doc":"- Timer reference","ref":"DeribitEx.RPC.html#generate_timeout_reference/1-returns"},{"type":"function","title":"DeribitEx.RPC.get_timeout/3","doc":"Gets the timeout value for a request.","ref":"DeribitEx.RPC.html#get_timeout/3"},{"type":"function","title":"Parameters - DeribitEx.RPC.get_timeout/3","doc":"- `method` - The JSON-RPC method\n- `options` - Request options that may include timeout\n- `state` - The adapter state which may have default timeouts","ref":"DeribitEx.RPC.html#get_timeout/3-parameters"},{"type":"function","title":"Returns - DeribitEx.RPC.get_timeout/3","doc":"- Timeout value in milliseconds","ref":"DeribitEx.RPC.html#get_timeout/3-returns"},{"type":"function","title":"DeribitEx.RPC.method_type/1","doc":"Classifies an RPC method as public, private, or unknown.\n\nThis is used for properly handling authentication requirements.","ref":"DeribitEx.RPC.html#method_type/1"},{"type":"function","title":"Parameters - DeribitEx.RPC.method_type/1","doc":"- `method` - The JSON-RPC method string","ref":"DeribitEx.RPC.html#method_type/1-parameters"},{"type":"function","title":"Returns - DeribitEx.RPC.method_type/1","doc":"- `:public` for public methods\n- `:private` for private methods\n- `:unknown` for unclassified methods","ref":"DeribitEx.RPC.html#method_type/1-returns"},{"type":"function","title":"Examples - DeribitEx.RPC.method_type/1","doc":"iex> RPC.method_type(\"public/auth\")\n    :public\n    \n    iex> RPC.method_type(\"private/get_position\")\n    :private","ref":"DeribitEx.RPC.html#method_type/1-examples"},{"type":"function","title":"DeribitEx.RPC.microseconds_to_datetime/1","doc":"Converts a timestamp from microseconds to DateTime.\n\nDeribit often provides timestamps in microseconds since epoch.","ref":"DeribitEx.RPC.html#microseconds_to_datetime/1"},{"type":"function","title":"Parameters - DeribitEx.RPC.microseconds_to_datetime/1","doc":"- `timestamp_us` - Timestamp in microseconds","ref":"DeribitEx.RPC.html#microseconds_to_datetime/1-parameters"},{"type":"function","title":"Returns - DeribitEx.RPC.microseconds_to_datetime/1","doc":"- DateTime struct representing the timestamp","ref":"DeribitEx.RPC.html#microseconds_to_datetime/1-returns"},{"type":"function","title":"Examples - DeribitEx.RPC.microseconds_to_datetime/1","doc":"iex> RPC.microseconds_to_datetime(1609459200000000)\n    ~U[2021-01-01 00:00:00Z]","ref":"DeribitEx.RPC.html#microseconds_to_datetime/1-examples"},{"type":"function","title":"DeribitEx.RPC.needs_reauth?/1","doc":"Checks if an error requires connection re-authentication.\n\nUsed to determine if authentication needs to be refreshed\nbased on specific Deribit error codes.","ref":"DeribitEx.RPC.html#needs_reauth?/1"},{"type":"function","title":"Parameters - DeribitEx.RPC.needs_reauth?/1","doc":"- `error` - The error map from the response","ref":"DeribitEx.RPC.html#needs_reauth?/1-parameters"},{"type":"function","title":"Returns - DeribitEx.RPC.needs_reauth?/1","doc":"- `true` if authentication needs to be refreshed\n- `false` otherwise","ref":"DeribitEx.RPC.html#needs_reauth?/1-returns"},{"type":"function","title":"Examples - DeribitEx.RPC.needs_reauth?/1","doc":"iex> RPC.needs_reauth?(%{\"code\" => 13010, \"message\" => \"Token expired\"})\n    true\n    \n    iex> RPC.needs_reauth?(%{\"code\" => 10001, \"message\" => \"Invalid parameter\"})\n    false","ref":"DeribitEx.RPC.html#needs_reauth?/1-examples"},{"type":"function","title":"DeribitEx.RPC.parse_response/1","doc":"Parses a JSON-RPC response based on its structure.","ref":"DeribitEx.RPC.html#parse_response/1"},{"type":"function","title":"Parameters - DeribitEx.RPC.parse_response/1","doc":"- `response` - The JSON-RPC response (map)","ref":"DeribitEx.RPC.html#parse_response/1-parameters"},{"type":"function","title":"Returns - DeribitEx.RPC.parse_response/1","doc":"- `{:ok, result}` - For successful responses with a result field\n- `{:error, error}` - For error responses\n- `{:error, {:invalid_response, response}}` - For invalid or unexpected responses","ref":"DeribitEx.RPC.html#parse_response/1-returns"},{"type":"function","title":"Examples - DeribitEx.RPC.parse_response/1","doc":"iex> RPC.parse_response(%{\"jsonrpc\" => \"2.0\", \"id\" => 123, \"result\" => \"success\"})\n    {:ok, \"success\"}\n    \n    iex> RPC.parse_response(%{\"jsonrpc\" => \"2.0\", \"id\" => 123, \"error\" => %{\"code\" => 10001, \"message\" => \"Error\"}})\n    {:error, %{\"code\" => 10001, \"message\" => \"Error\"}}","ref":"DeribitEx.RPC.html#parse_response/1-examples"},{"type":"function","title":"DeribitEx.RPC.remove_tracked_request/2","doc":"Removes a tracked request from state once processed.","ref":"DeribitEx.RPC.html#remove_tracked_request/2"},{"type":"function","title":"Parameters - DeribitEx.RPC.remove_tracked_request/2","doc":"- `state` - The current adapter state\n- `id` - The request ID to remove","ref":"DeribitEx.RPC.html#remove_tracked_request/2-parameters"},{"type":"function","title":"Returns - DeribitEx.RPC.remove_tracked_request/2","doc":"- Updated state with the request removed","ref":"DeribitEx.RPC.html#remove_tracked_request/2-returns"},{"type":"function","title":"DeribitEx.RPC.requires_auth?/1","doc":"Determines if a method requires authentication.","ref":"DeribitEx.RPC.html#requires_auth?/1"},{"type":"function","title":"Parameters - DeribitEx.RPC.requires_auth?/1","doc":"- `method` - The JSON-RPC method string","ref":"DeribitEx.RPC.html#requires_auth?/1-parameters"},{"type":"function","title":"Returns - DeribitEx.RPC.requires_auth?/1","doc":"- `true` if authentication is required\n- `false` otherwise","ref":"DeribitEx.RPC.html#requires_auth?/1-returns"},{"type":"function","title":"Examples - DeribitEx.RPC.requires_auth?/1","doc":"iex> RPC.requires_auth?(\"private/get_position\")\n    true\n    \n    iex> RPC.requires_auth?(\"public/get_time\")\n    false","ref":"DeribitEx.RPC.html#requires_auth?/1-examples"},{"type":"function","title":"DeribitEx.RPC.track_request/5","doc":"Tracks a new request in the state for later matching with response.","ref":"DeribitEx.RPC.html#track_request/5"},{"type":"function","title":"Parameters - DeribitEx.RPC.track_request/5","doc":"- `state` - The current adapter state\n- `id` - The request ID\n- `method` - The JSON-RPC method\n- `params` - The request parameters\n- `options` - Optional request options","ref":"DeribitEx.RPC.html#track_request/5-parameters"},{"type":"function","title":"Returns - DeribitEx.RPC.track_request/5","doc":"- Updated state with the request tracked","ref":"DeribitEx.RPC.html#track_request/5-returns"},{"type":"module","title":"DeribitEx.SessionContext","doc":"Manages session context and order state preservation during Deribit token operations.\n\nThis module tracks the state of sessions across token changes and provides \nfunctionality for preserving order state during session transitions. It handles:\n\n- Session tracking during token exchange (switching subaccounts)\n- Session tracking during token forking (creating named sessions)\n- Order state preservation across session transitions\n- Automatic channel resubscription after token changes\n\nIntegrates with both token management and order management to ensure\ncontinuity of operations during authentication changes.","ref":"DeribitEx.SessionContext.html"},{"type":"function","title":"DeribitEx.SessionContext.generate_session_id/0","doc":"Generates a unique session ID.\n\nUses a combination of timestamp and random bytes for uniqueness.","ref":"DeribitEx.SessionContext.html#generate_session_id/0"},{"type":"function","title":"DeribitEx.SessionContext.invalidate/1","doc":"Invalidates a session during logout operations.","ref":"DeribitEx.SessionContext.html#invalidate/1"},{"type":"function","title":"Parameters - DeribitEx.SessionContext.invalidate/1","doc":"- `current_session` - The session to invalidate","ref":"DeribitEx.SessionContext.html#invalidate/1-parameters"},{"type":"function","title":"Returns - DeribitEx.SessionContext.invalidate/1","doc":"- `{:ok, session}` - Invalidated session","ref":"DeribitEx.SessionContext.html#invalidate/1-returns"},{"type":"function","title":"DeribitEx.SessionContext.new_from_auth/2","doc":"Creates a new SessionContext from authentication response data.\n\nUsed when first authenticating to create the initial session context.","ref":"DeribitEx.SessionContext.html#new_from_auth/2"},{"type":"function","title":"Parameters - DeribitEx.SessionContext.new_from_auth/2","doc":"- `auth_data` - Authentication response from Deribit containing access_token, etc.\n- `opts` - Additional options for session creation","ref":"DeribitEx.SessionContext.html#new_from_auth/2-parameters"},{"type":"function","title":"Returns - DeribitEx.SessionContext.new_from_auth/2","doc":"- `{:ok, session}` - A new session context","ref":"DeribitEx.SessionContext.html#new_from_auth/2-returns"},{"type":"function","title":"DeribitEx.SessionContext.new_from_exchange/3","doc":"Creates a new SessionContext from a token exchange response.\n\nUsed when switching between subaccounts to track the session transition.","ref":"DeribitEx.SessionContext.html#new_from_exchange/3"},{"type":"function","title":"Parameters - DeribitEx.SessionContext.new_from_exchange/3","doc":"- `current_session` - The current active session\n- `exchange_data` - Response from exchange_token operation\n- `subject_id` - The ID of the subaccount being switched to","ref":"DeribitEx.SessionContext.html#new_from_exchange/3-parameters"},{"type":"function","title":"Returns - DeribitEx.SessionContext.new_from_exchange/3","doc":"- `{:ok, session}` - A new session context with transition tracking","ref":"DeribitEx.SessionContext.html#new_from_exchange/3-returns"},{"type":"function","title":"DeribitEx.SessionContext.new_from_fork/3","doc":"Creates a new SessionContext from a token fork response.\n\nUsed when creating a named session to track the session transition.","ref":"DeribitEx.SessionContext.html#new_from_fork/3"},{"type":"function","title":"Parameters - DeribitEx.SessionContext.new_from_fork/3","doc":"- `current_session` - The current active session\n- `fork_data` - Response from fork_token operation\n- `session_name` - The name of the new session being created","ref":"DeribitEx.SessionContext.html#new_from_fork/3-parameters"},{"type":"function","title":"Returns - DeribitEx.SessionContext.new_from_fork/3","doc":"- `{:ok, session}` - A new session context with transition tracking","ref":"DeribitEx.SessionContext.html#new_from_fork/3-returns"},{"type":"type","title":"DeribitEx.SessionContext.t/0","doc":"Represents a Deribit session with tracking information.\n\n- `id`: Unique ID for this session\n- `prev_id`: ID of the previous session (for tracking transitions)\n- `created_at`: When this session was created\n- `access_token`: Current access token for this session\n- `refresh_token`: Current refresh token for this session\n- `expires_at`: When the current token will expire\n- `transition`: How this session was created\n- `subject_id`: Account ID for this session (from exchange_token)\n- `session_name`: Session name (from fork_token)\n- `scope`: Authentication permissions for this session\n- `active`: Whether this session is currently active","ref":"DeribitEx.SessionContext.html#t:t/0"},{"type":"type","title":"DeribitEx.SessionContext.transition_type/0","doc":"The session transition type:\n- `:exchange` - Token exchange for switching subaccounts\n- `:fork` - Token fork for creating named sessions\n- `:refresh` - Normal token refresh within same session\n- `:initial` - Initial session creation","ref":"DeribitEx.SessionContext.html#t:transition_type/0"},{"type":"function","title":"DeribitEx.SessionContext.update_from_refresh/2","doc":"Updates an existing SessionContext with refreshed token data.\n\nUsed during normal token refresh operations to maintain session continuity.","ref":"DeribitEx.SessionContext.html#update_from_refresh/2"},{"type":"function","title":"Parameters - DeribitEx.SessionContext.update_from_refresh/2","doc":"- `current_session` - The current active session\n- `refresh_data` - Response from token refresh operation","ref":"DeribitEx.SessionContext.html#update_from_refresh/2-parameters"},{"type":"function","title":"Returns - DeribitEx.SessionContext.update_from_refresh/2","doc":"- `{:ok, session}` - Updated session context with new token information","ref":"DeribitEx.SessionContext.html#update_from_refresh/2-returns"},{"type":"module","title":"DeribitEx.TokenManager","doc":"Integrates token management with order management.\n\nThis module provides the central integration point for token operations and\norder management, handling session transitions, order state preservation,\nand resubscription. It coordinates:\n\n- Session tracking via SessionContext\n- Order state preservation via OrderContext\n- Channel resubscription via ResubscriptionHandler\n\nDesigned to be used by Adapter to perform token operations while\npreserving application state.","ref":"DeribitEx.TokenManager.html"},{"type":"function","title":"DeribitEx.TokenManager.get_active_orders/1","doc":"Gets all active orders for the current session.","ref":"DeribitEx.TokenManager.html#get_active_orders/1"},{"type":"function","title":"Parameters - DeribitEx.TokenManager.get_active_orders/1","doc":"- `manager`: Current token manager state","ref":"DeribitEx.TokenManager.html#get_active_orders/1-parameters"},{"type":"function","title":"Returns - DeribitEx.TokenManager.get_active_orders/1","doc":"- `{:ok, orders}`: List of active orders\n- `{:error, :no_active_session}`: If no active session exists","ref":"DeribitEx.TokenManager.html#get_active_orders/1-returns"},{"type":"function","title":"DeribitEx.TokenManager.get_session_id/1","doc":"Gets the current session ID if available.","ref":"DeribitEx.TokenManager.html#get_session_id/1"},{"type":"function","title":"Parameters - DeribitEx.TokenManager.get_session_id/1","doc":"- `manager`: Current token manager state","ref":"DeribitEx.TokenManager.html#get_session_id/1-parameters"},{"type":"function","title":"Returns - DeribitEx.TokenManager.get_session_id/1","doc":"- `{:ok, session_id}`: The current session ID\n- `{:error, :no_active_session}`: If no active session exists","ref":"DeribitEx.TokenManager.html#get_session_id/1-returns"},{"type":"function","title":"DeribitEx.TokenManager.handle_exchange_token/3","doc":"Handles a token exchange operation for switching subaccounts.","ref":"DeribitEx.TokenManager.html#handle_exchange_token/3"},{"type":"function","title":"Parameters - DeribitEx.TokenManager.handle_exchange_token/3","doc":"- `manager`: Current token manager state\n- `exchange_data`: Response from exchange_token operation\n- `subject_id`: The ID of the subaccount being switched to","ref":"DeribitEx.TokenManager.html#handle_exchange_token/3-parameters"},{"type":"function","title":"Returns - DeribitEx.TokenManager.handle_exchange_token/3","doc":"- `{:ok, updated_manager}`: Updated token manager with new session\n- `{:error, reason}`: If the operation fails","ref":"DeribitEx.TokenManager.html#handle_exchange_token/3-returns"},{"type":"function","title":"DeribitEx.TokenManager.handle_fork_token/3","doc":"Handles a token fork operation for creating a named session.","ref":"DeribitEx.TokenManager.html#handle_fork_token/3"},{"type":"function","title":"Parameters - DeribitEx.TokenManager.handle_fork_token/3","doc":"- `manager`: Current token manager state\n- `fork_data`: Response from fork_token operation\n- `session_name`: The name of the new session being created","ref":"DeribitEx.TokenManager.html#handle_fork_token/3-parameters"},{"type":"function","title":"Returns - DeribitEx.TokenManager.handle_fork_token/3","doc":"- `{:ok, updated_manager}`: Updated token manager with new session\n- `{:error, reason}`: If the operation fails","ref":"DeribitEx.TokenManager.html#handle_fork_token/3-returns"},{"type":"function","title":"DeribitEx.TokenManager.handle_logout/1","doc":"Handles logout and session invalidation.","ref":"DeribitEx.TokenManager.html#handle_logout/1"},{"type":"function","title":"Parameters - DeribitEx.TokenManager.handle_logout/1","doc":"- `manager`: Current token manager state","ref":"DeribitEx.TokenManager.html#handle_logout/1-parameters"},{"type":"function","title":"Returns - DeribitEx.TokenManager.handle_logout/1","doc":"- `{:ok, updated_manager}`: Updated token manager with invalidated session","ref":"DeribitEx.TokenManager.html#handle_logout/1-returns"},{"type":"function","title":"DeribitEx.TokenManager.handle_token_refresh/2","doc":"Handles a token refresh operation.","ref":"DeribitEx.TokenManager.html#handle_token_refresh/2"},{"type":"function","title":"Parameters - DeribitEx.TokenManager.handle_token_refresh/2","doc":"- `manager`: Current token manager state\n- `refresh_data`: Response from token refresh operation","ref":"DeribitEx.TokenManager.html#handle_token_refresh/2-parameters"},{"type":"function","title":"Returns - DeribitEx.TokenManager.handle_token_refresh/2","doc":"- `{:ok, updated_manager}`: Updated token manager with refreshed session\n- `{:error, reason}`: If the operation fails","ref":"DeribitEx.TokenManager.html#handle_token_refresh/2-returns"},{"type":"function","title":"DeribitEx.TokenManager.init_from_auth/3","doc":"Initializes the token manager from an authentication response.","ref":"DeribitEx.TokenManager.html#init_from_auth/3"},{"type":"function","title":"Parameters - DeribitEx.TokenManager.init_from_auth/3","doc":"- `manager`: Current token manager state\n- `auth_data`: Authentication response from Deribit\n- `opts`: Additional options","ref":"DeribitEx.TokenManager.html#init_from_auth/3-parameters"},{"type":"function","title":"Returns - DeribitEx.TokenManager.init_from_auth/3","doc":"- `{:ok, updated_manager}`: Updated token manager with session context","ref":"DeribitEx.TokenManager.html#init_from_auth/3-returns"},{"type":"function","title":"DeribitEx.TokenManager.new/1","doc":"Creates a new TokenManager instance.","ref":"DeribitEx.TokenManager.html#new/1"},{"type":"function","title":"Parameters - DeribitEx.TokenManager.new/1","doc":"- `opts`: Options for the token manager\n  - `:max_retries` - Maximum resubscription retry attempts (default: 3)","ref":"DeribitEx.TokenManager.html#new/1-parameters"},{"type":"function","title":"Returns - DeribitEx.TokenManager.new/1","doc":"- A new TokenManager instance","ref":"DeribitEx.TokenManager.html#new/1-returns"},{"type":"function","title":"DeribitEx.TokenManager.perform_resubscription/2","doc":"Performs resubscription for all tracked channels.","ref":"DeribitEx.TokenManager.html#perform_resubscription/2"},{"type":"function","title":"Parameters - DeribitEx.TokenManager.perform_resubscription/2","doc":"- `manager`: Current token manager state\n- `conn`: WebsockexNova client connection","ref":"DeribitEx.TokenManager.html#perform_resubscription/2-parameters"},{"type":"function","title":"Returns - DeribitEx.TokenManager.perform_resubscription/2","doc":"- `{:ok, updated_manager, results}`: Updated manager and resubscription results\n- `{:error, reason, updated_manager}`: Error information if resubscription fails","ref":"DeribitEx.TokenManager.html#perform_resubscription/2-returns"},{"type":"function","title":"DeribitEx.TokenManager.register_order/2","doc":"Registers a new order with the token manager.","ref":"DeribitEx.TokenManager.html#register_order/2"},{"type":"function","title":"Parameters - DeribitEx.TokenManager.register_order/2","doc":"- `manager`: Current token manager state\n- `order`: Order information","ref":"DeribitEx.TokenManager.html#register_order/2-parameters"},{"type":"function","title":"Returns - DeribitEx.TokenManager.register_order/2","doc":"- `{:ok, updated_manager}`: Updated token manager with order registered\n- `{:error, reason}`: If the operation fails","ref":"DeribitEx.TokenManager.html#register_order/2-returns"},{"type":"function","title":"DeribitEx.TokenManager.register_subscription/3","doc":"Registers a new subscription with the token manager.","ref":"DeribitEx.TokenManager.html#register_subscription/3"},{"type":"function","title":"Parameters - DeribitEx.TokenManager.register_subscription/3","doc":"- `manager`: Current token manager state\n- `channel`: Channel name or topic\n- `params`: Subscription parameters","ref":"DeribitEx.TokenManager.html#register_subscription/3-parameters"},{"type":"function","title":"Returns - DeribitEx.TokenManager.register_subscription/3","doc":"- `{:ok, updated_manager}`: Updated token manager with subscription registered\n- `{:error, reason}`: If the operation fails","ref":"DeribitEx.TokenManager.html#register_subscription/3-returns"},{"type":"type","title":"DeribitEx.TokenManager.t/0","doc":"The complete token management state.\n\n- `session`: Current session context\n- `orders`: Order tracking context\n- `resubscription`: Channel resubscription handler","ref":"DeribitEx.TokenManager.html#t:t/0"},{"type":"function","title":"DeribitEx.TokenManager.unregister_subscription/2","doc":"Unregisters a subscription from the token manager.","ref":"DeribitEx.TokenManager.html#unregister_subscription/2"},{"type":"function","title":"Parameters - DeribitEx.TokenManager.unregister_subscription/2","doc":"- `manager`: Current token manager state\n- `channel`: Channel to unregister","ref":"DeribitEx.TokenManager.html#unregister_subscription/2-parameters"},{"type":"function","title":"Returns - DeribitEx.TokenManager.unregister_subscription/2","doc":"- `{:ok, updated_manager}`: Updated token manager with subscription removed","ref":"DeribitEx.TokenManager.html#unregister_subscription/2-returns"},{"type":"function","title":"DeribitEx.TokenManager.update_order/2","doc":"Updates an existing order in the token manager.","ref":"DeribitEx.TokenManager.html#update_order/2"},{"type":"function","title":"Parameters - DeribitEx.TokenManager.update_order/2","doc":"- `manager`: Current token manager state\n- `order`: Updated order information","ref":"DeribitEx.TokenManager.html#update_order/2-parameters"},{"type":"function","title":"Returns - DeribitEx.TokenManager.update_order/2","doc":"- `{:ok, updated_manager}`: Updated token manager with order updated\n- `{:error, reason}`: If the operation fails","ref":"DeribitEx.TokenManager.html#update_order/2-returns"},{"type":"module","title":"DeribitEx.RateLimitHandler","doc":"Adaptive rate limit handler for Deribit WebSocket API.\n\nThis module implements the WebsockexNova.Behaviors.RateLimitHandler\nbehavior with adaptive rate limiting capabilities:\n\n- Dynamically adjusts rate limits based on 429 responses from Deribit\n- Implements exponential backoff when rate limits are hit\n- Prioritizes critical operations like order cancellation\n- Recovers rate limits gradually after backoff periods\n- Emits detailed telemetry for monitoring rate limiting behavior","ref":"DeribitEx.RateLimitHandler.html"},{"type":"module","title":"Configuration Options - DeribitEx.RateLimitHandler","doc":"Three rate limit modes are supported:\n- `:cautious` - Strict limits to avoid 429s completely\n- `:normal` - Balanced approach \n- `:aggressive` - Higher throughput, might get occasional 429s","ref":"DeribitEx.RateLimitHandler.html#module-configuration-options"},{"type":"module","title":"Backoff Strategy - DeribitEx.RateLimitHandler","doc":"When a 429 response is received:\n1. The handler reduces the rate limit by the recovery_factor\n2. It applies a backoff multiplier to delay subsequent requests\n3. The backoff multiplier increases with consecutive 429s\n4. The rate limit gradually recovers over time","ref":"DeribitEx.RateLimitHandler.html#module-backoff-strategy"},{"type":"type","title":"DeribitEx.RateLimitHandler.adaptive_state/0","doc":"Adaptive state for the rate limiter.","ref":"DeribitEx.RateLimitHandler.html#t:adaptive_state/0"},{"type":"type","title":"DeribitEx.RateLimitHandler.bucket_state/0","doc":"Token bucket state for the rate limiter.","ref":"DeribitEx.RateLimitHandler.html#t:bucket_state/0"},{"type":"function","title":"DeribitEx.RateLimitHandler.check_rate_limit/2","doc":"Checks if a request should be rate limited.\n\nThis is the main entry point for the rate limiting handler and is called\nfor every request sent to the WebSocket API.","ref":"DeribitEx.RateLimitHandler.html#check_rate_limit/2"},{"type":"function","title":"Parameters - DeribitEx.RateLimitHandler.check_rate_limit/2","doc":"* `request` - The request to be rate limited (map or JSON string)\n  * `state` - Current rate limiter state","ref":"DeribitEx.RateLimitHandler.html#check_rate_limit/2-parameters"},{"type":"function","title":"Returns - DeribitEx.RateLimitHandler.check_rate_limit/2","doc":"* `{:ok, state}` - Request is allowed, with updated state\n  * `{:backoff, delay_ms, state}` - Request should be delayed by specified ms","ref":"DeribitEx.RateLimitHandler.html#check_rate_limit/2-returns"},{"type":"type","title":"DeribitEx.RateLimitHandler.config/0","doc":"Configuration for the rate limiter.","ref":"DeribitEx.RateLimitHandler.html#t:config/0"},{"type":"type","title":"DeribitEx.RateLimitHandler.cost_map/0","doc":"Cost map specifying token costs for different operation types.","ref":"DeribitEx.RateLimitHandler.html#t:cost_map/0"},{"type":"function","title":"DeribitEx.RateLimitHandler.current_time_ms/0","doc":"","ref":"DeribitEx.RateLimitHandler.html#current_time_ms/0"},{"type":"function","title":"DeribitEx.RateLimitHandler.handle_tick/1","doc":"Handles the rate limiter tick (called periodically by WebsockexNova).\n\nThis is used for processing responses and adjusting rate limits based on\n429 responses from the Deribit API.","ref":"DeribitEx.RateLimitHandler.html#handle_tick/1"},{"type":"function","title":"Parameters - DeribitEx.RateLimitHandler.handle_tick/1","doc":"* `state` - Current rate limiter state","ref":"DeribitEx.RateLimitHandler.html#handle_tick/1-parameters"},{"type":"function","title":"Returns - DeribitEx.RateLimitHandler.handle_tick/1","doc":"* `{:ok, state}` - Updated state after tick processing","ref":"DeribitEx.RateLimitHandler.html#handle_tick/1-returns"},{"type":"type","title":"DeribitEx.RateLimitHandler.operation_type/0","doc":"Operation types that can be rate limited.","ref":"DeribitEx.RateLimitHandler.html#t:operation_type/0"},{"type":"function","title":"DeribitEx.RateLimitHandler.rate_limit_init/1","doc":"Initializes rate limit state with token bucket and adaptive parameters.","ref":"DeribitEx.RateLimitHandler.html#rate_limit_init/1"},{"type":"function","title":"Parameters - DeribitEx.RateLimitHandler.rate_limit_init/1","doc":"* `opts` - Configuration options for the rate limiter:\n    * `:mode` - Rate limiting mode (:cautious, :normal, :aggressive)\n    * `:cost_map` - Map of operation costs\n    * `:capacity` - Override token bucket capacity\n    * `:refill_rate` - Override token refill rate\n    * `:refill_interval` - Override token refill interval\n    * `:queue_limit` - Maximum queue size for delayed requests\n    * `:adaptive` - Adaptive rate limiting options:\n      * `:backoff_initial` - Initial backoff multiplier when 429 is hit\n      * `:backoff_max` - Maximum backoff multiplier\n      * `:backoff_reset_after` - Time after which backoff resets (ms)\n      * `:recovery_factor` - Factor to reduce capacity by when 429 is hit\n      * `:recovery_increase` - Rate at which capacity recovers\n      * `:recovery_interval` - Interval between capacity recovery attempts\n      * `:telemetry_prefix` - Prefix for telemetry events","ref":"DeribitEx.RateLimitHandler.html#rate_limit_init/1-parameters"},{"type":"function","title":"Returns - DeribitEx.RateLimitHandler.rate_limit_init/1","doc":"* `{:ok, state}` - Initialized rate limiter state","ref":"DeribitEx.RateLimitHandler.html#rate_limit_init/1-returns"},{"type":"type","title":"DeribitEx.RateLimitHandler.rate_limit_mode/0","doc":"Rate limiting modes that determine token bucket parameters.","ref":"DeribitEx.RateLimitHandler.html#t:rate_limit_mode/0"},{"type":"type","title":"DeribitEx.RateLimitHandler.request_info/0","doc":"Request handler tracking information.","ref":"DeribitEx.RateLimitHandler.html#t:request_info/0"},{"type":"type","title":"DeribitEx.RateLimitHandler.state/0","doc":"Overall state for the rate limiter.","ref":"DeribitEx.RateLimitHandler.html#t:state/0"},{"type":"module","title":"DeribitEx.ResubscriptionHandler","doc":"Handles automatic resubscription to channels after token changes.\n\nThis module is responsible for:\n- Tracking channels that need to be resubscribed after token changes\n- Providing a mechanism to resubscribe to channels automatically\n- Handling both public and private channel resubscriptions\n- Managing resubscription failures and retries\n\nIntegrates with the Adapter and Client to ensure\nsubscriptions are maintained during token operations.","ref":"DeribitEx.ResubscriptionHandler.html"},{"type":"function","title":"DeribitEx.ResubscriptionHandler.handle_session_transition/3","doc":"Notifies the resubscription handler of a session transition.","ref":"DeribitEx.ResubscriptionHandler.html#handle_session_transition/3"},{"type":"function","title":"Parameters - DeribitEx.ResubscriptionHandler.handle_session_transition/3","doc":"- `state`: Current resubscription state\n- `prev_session`: Previous session\n- `new_session`: New session after token change","ref":"DeribitEx.ResubscriptionHandler.html#handle_session_transition/3-parameters"},{"type":"function","title":"Returns - DeribitEx.ResubscriptionHandler.handle_session_transition/3","doc":"- `{:ok, updated_state}`: Updated state with resubscription flag set","ref":"DeribitEx.ResubscriptionHandler.html#handle_session_transition/3-returns"},{"type":"function","title":"DeribitEx.ResubscriptionHandler.is_private_channel?/1","doc":"Determines if a channel requires authentication.","ref":"DeribitEx.ResubscriptionHandler.html#is_private_channel?/1"},{"type":"function","title":"Parameters - DeribitEx.ResubscriptionHandler.is_private_channel?/1","doc":"- `channel`: Channel name to check","ref":"DeribitEx.ResubscriptionHandler.html#is_private_channel?/1-parameters"},{"type":"function","title":"Returns - DeribitEx.ResubscriptionHandler.is_private_channel?/1","doc":"- `true` if the channel is private (requires authentication)\n- `false` if the channel is public","ref":"DeribitEx.ResubscriptionHandler.html#is_private_channel?/1-returns"},{"type":"function","title":"DeribitEx.ResubscriptionHandler.new/1","doc":"Creates a new resubscription handler state.","ref":"DeribitEx.ResubscriptionHandler.html#new/1"},{"type":"function","title":"Parameters - DeribitEx.ResubscriptionHandler.new/1","doc":"- `opts`: Options for the handler\n  - `:max_retries` - Maximum resubscription retry attempts (default: 3)","ref":"DeribitEx.ResubscriptionHandler.html#new/1-parameters"},{"type":"function","title":"Returns - DeribitEx.ResubscriptionHandler.new/1","doc":"- A new empty resubscription state","ref":"DeribitEx.ResubscriptionHandler.html#new/1-returns"},{"type":"function","title":"DeribitEx.ResubscriptionHandler.perform_resubscription/2","doc":"Performs resubscription for all tracked channels.\n\nShould be called after authentication completes with a new token.","ref":"DeribitEx.ResubscriptionHandler.html#perform_resubscription/2"},{"type":"function","title":"Parameters - DeribitEx.ResubscriptionHandler.perform_resubscription/2","doc":"- `state`: Current resubscription state\n- `conn`: WebsockexNova client connection","ref":"DeribitEx.ResubscriptionHandler.html#perform_resubscription/2-parameters"},{"type":"function","title":"Returns - DeribitEx.ResubscriptionHandler.perform_resubscription/2","doc":"- `{:ok, updated_state, results}`: Updated state and resubscription results\n- `{:error, reason, state}`: Error information if resubscription fails","ref":"DeribitEx.ResubscriptionHandler.html#perform_resubscription/2-returns"},{"type":"function","title":"DeribitEx.ResubscriptionHandler.register_subscription/4","doc":"Registers a channel subscription for potential resubscription.","ref":"DeribitEx.ResubscriptionHandler.html#register_subscription/4"},{"type":"function","title":"Parameters - DeribitEx.ResubscriptionHandler.register_subscription/4","doc":"- `state`: Current resubscription state\n- `channel`: Channel name or topic\n- `params`: Subscription parameters used for this channel\n- `session_id`: ID of the session that created the subscription","ref":"DeribitEx.ResubscriptionHandler.html#register_subscription/4-parameters"},{"type":"function","title":"Returns - DeribitEx.ResubscriptionHandler.register_subscription/4","doc":"- `{:ok, updated_state}`: Updated state with the registered channel","ref":"DeribitEx.ResubscriptionHandler.html#register_subscription/4-returns"},{"type":"function","title":"DeribitEx.ResubscriptionHandler.subscribe_to_channel/3","doc":"Performs token-aware subscription to a channel.","ref":"DeribitEx.ResubscriptionHandler.html#subscribe_to_channel/3"},{"type":"function","title":"Parameters - DeribitEx.ResubscriptionHandler.subscribe_to_channel/3","doc":"- `conn`: WebsockexNova client connection\n- `channel`: Channel to subscribe to\n- `params`: Subscription parameters","ref":"DeribitEx.ResubscriptionHandler.html#subscribe_to_channel/3-parameters"},{"type":"function","title":"Returns - DeribitEx.ResubscriptionHandler.subscribe_to_channel/3","doc":"- `{:ok, subscription}`: Successful subscription\n- `{:error, reason}`: If subscription fails","ref":"DeribitEx.ResubscriptionHandler.html#subscribe_to_channel/3-returns"},{"type":"type","title":"DeribitEx.ResubscriptionHandler.t/0","doc":"Represents channel resubscription state tracking.\n\n- `channels`: Map of channel name to subscription parameters\n- `active_session_id`: ID of the currently active session\n- `resubscription_in_progress`: Flag to track when resubscription is happening\n- `resubscribe_after_auth`: Flag to indicate resubscription needed after authentication\n- `retry_count`: Counter for resubscription attempts\n- `max_retries`: Maximum number of resubscription retries","ref":"DeribitEx.ResubscriptionHandler.html#t:t/0"},{"type":"function","title":"DeribitEx.ResubscriptionHandler.unregister_subscription/2","doc":"Removes a channel subscription from tracking.","ref":"DeribitEx.ResubscriptionHandler.html#unregister_subscription/2"},{"type":"function","title":"Parameters - DeribitEx.ResubscriptionHandler.unregister_subscription/2","doc":"- `state`: Current resubscription state\n- `channel`: Channel to unregister","ref":"DeribitEx.ResubscriptionHandler.html#unregister_subscription/2-parameters"},{"type":"function","title":"Returns - DeribitEx.ResubscriptionHandler.unregister_subscription/2","doc":"- `{:ok, updated_state}`: Updated state without the channel","ref":"DeribitEx.ResubscriptionHandler.html#unregister_subscription/2-returns"},{"type":"module","title":"DeribitEx.TimeSyncService","doc":"A dedicated service for maintaining and tracking the time delta between the local system\nand the Deribit server. This service periodically synchronizes with the Deribit server time\nto ensure accurate timing for operations that depend on server time.","ref":"DeribitEx.TimeSyncService.html"},{"type":"module","title":"Features - DeribitEx.TimeSyncService","doc":"* Periodically polls the server time to calculate time drift\n  * Provides functions to convert between local and server time\n  * Automatically adjusts for network latency in time calculations\n  * Uses a GenServer with configurable synchronization interval","ref":"DeribitEx.TimeSyncService.html#module-features"},{"type":"module","title":"Usage - DeribitEx.TimeSyncService","doc":"```elixir\n  # Start the service\n  {:ok, pid} = TimeSyncService.start_link(client_pid)\n\n  # Get the current server time (in milliseconds)\n  server_time_ms = TimeSyncService.server_time()\n\n  # Convert local time to server time\n  server_time = TimeSyncService.local_to_server(System.system_time(:millisecond))\n\n  # Convert server time to local time\n  local_time = TimeSyncService.server_to_local(server_time_ms)\n  ```","ref":"DeribitEx.TimeSyncService.html#module-usage"},{"type":"function","title":"DeribitEx.TimeSyncService.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"DeribitEx.TimeSyncService.html#child_spec/1"},{"type":"function","title":"DeribitEx.TimeSyncService.get_time_delta/1","doc":"Gets the current time delta between local and server time in milliseconds.","ref":"DeribitEx.TimeSyncService.html#get_time_delta/1"},{"type":"function","title":"Parameters - DeribitEx.TimeSyncService.get_time_delta/1","doc":"* `server` - The TimeSyncService server (default: __MODULE__)","ref":"DeribitEx.TimeSyncService.html#get_time_delta/1-parameters"},{"type":"function","title":"Returns - DeribitEx.TimeSyncService.get_time_delta/1","doc":"* The time delta in milliseconds (server_time - local_time)\n  * Returns 0 if the service has not yet successfully synchronized","ref":"DeribitEx.TimeSyncService.html#get_time_delta/1-returns"},{"type":"function","title":"DeribitEx.TimeSyncService.local_to_server/2","doc":"Converts a local timestamp to the corresponding server timestamp.","ref":"DeribitEx.TimeSyncService.html#local_to_server/2"},{"type":"function","title":"Parameters - DeribitEx.TimeSyncService.local_to_server/2","doc":"* `local_time_ms` - Local time in milliseconds since epoch\n  * `server` - The TimeSyncService server (default: __MODULE__)","ref":"DeribitEx.TimeSyncService.html#local_to_server/2-parameters"},{"type":"function","title":"Returns - DeribitEx.TimeSyncService.local_to_server/2","doc":"* The corresponding server time in milliseconds","ref":"DeribitEx.TimeSyncService.html#local_to_server/2-returns"},{"type":"type","title":"DeribitEx.TimeSyncService.server/0","doc":"Time synchronization service server identifier.","ref":"DeribitEx.TimeSyncService.html#t:server/0"},{"type":"function","title":"DeribitEx.TimeSyncService.server_time/1","doc":"Gets the current estimated server time in milliseconds since epoch.","ref":"DeribitEx.TimeSyncService.html#server_time/1"},{"type":"function","title":"Returns - DeribitEx.TimeSyncService.server_time/1","doc":"* The current server time in milliseconds","ref":"DeribitEx.TimeSyncService.html#server_time/1-returns"},{"type":"function","title":"DeribitEx.TimeSyncService.server_to_local/2","doc":"Converts a server timestamp to the corresponding local timestamp.","ref":"DeribitEx.TimeSyncService.html#server_to_local/2"},{"type":"function","title":"Parameters - DeribitEx.TimeSyncService.server_to_local/2","doc":"* `server_time_ms` - Server time in milliseconds since epoch\n  * `server` - The TimeSyncService server (default: __MODULE__)","ref":"DeribitEx.TimeSyncService.html#server_to_local/2-parameters"},{"type":"function","title":"Returns - DeribitEx.TimeSyncService.server_to_local/2","doc":"* The corresponding local time in milliseconds","ref":"DeribitEx.TimeSyncService.html#server_to_local/2-returns"},{"type":"function","title":"DeribitEx.TimeSyncService.start_link/2","doc":"Starts the TimeSyncService linked to the caller.","ref":"DeribitEx.TimeSyncService.html#start_link/2"},{"type":"function","title":"Parameters - DeribitEx.TimeSyncService.start_link/2","doc":"* `client_pid` - The PID of the Client connection\n  * `opts` - Options for the time sync service:\n    * `:sync_interval` - Interval between time syncs in milliseconds (default: 300_000 ms / 5 minutes)\n    * `:name` - Optional registration name for the server","ref":"DeribitEx.TimeSyncService.html#start_link/2-parameters"},{"type":"function","title":"Returns - DeribitEx.TimeSyncService.start_link/2","doc":"* `{:ok, pid}` - The PID of the started service\n  * `{:error, reason}` - If the service could not be started","ref":"DeribitEx.TimeSyncService.html#start_link/2-returns"},{"type":"type","title":"DeribitEx.TimeSyncService.start_options/0","doc":"Options for starting the TimeSyncService.","ref":"DeribitEx.TimeSyncService.html#t:start_options/0"},{"type":"type","title":"DeribitEx.TimeSyncService.state/0","doc":"Internal state of the TimeSyncService.","ref":"DeribitEx.TimeSyncService.html#t:state/0"},{"type":"type","title":"DeribitEx.TimeSyncService.sync_info/0","doc":"Synchronization information returned by sync_info/1.","ref":"DeribitEx.TimeSyncService.html#t:sync_info/0"},{"type":"function","title":"DeribitEx.TimeSyncService.sync_info/1","doc":"Returns information about the last synchronization.","ref":"DeribitEx.TimeSyncService.html#sync_info/1"},{"type":"function","title":"Parameters - DeribitEx.TimeSyncService.sync_info/1","doc":"* `server` - The TimeSyncService server (default: __MODULE__)","ref":"DeribitEx.TimeSyncService.html#sync_info/1-parameters"},{"type":"function","title":"Returns - DeribitEx.TimeSyncService.sync_info/1","doc":"* A map containing `:delta` and `:last_sync` (timestamp of last successful sync)\n  * Returns nil for `:last_sync` if no successful synchronization has occurred yet","ref":"DeribitEx.TimeSyncService.html#sync_info/1-returns"},{"type":"function","title":"DeribitEx.TimeSyncService.sync_now/1","doc":"Forces an immediate time synchronization.","ref":"DeribitEx.TimeSyncService.html#sync_now/1"},{"type":"function","title":"Parameters - DeribitEx.TimeSyncService.sync_now/1","doc":"* `server` - The TimeSyncService server (default: __MODULE__)","ref":"DeribitEx.TimeSyncService.html#sync_now/1-parameters"},{"type":"function","title":"Returns - DeribitEx.TimeSyncService.sync_now/1","doc":"* `:ok` - Synchronization request was submitted","ref":"DeribitEx.TimeSyncService.html#sync_now/1-returns"},{"type":"type","title":"DeribitEx.TimeSyncService.time_delta/0","doc":"Delta between server and local time in milliseconds.","ref":"DeribitEx.TimeSyncService.html#t:time_delta/0"},{"type":"type","title":"DeribitEx.TimeSyncService.time_ms/0","doc":"Time in milliseconds since epoch.","ref":"DeribitEx.TimeSyncService.html#t:time_ms/0"},{"type":"module","title":"DeribitEx.TimeSyncSupervisor","doc":"Supervisor for the TimeSyncService.\n\nThis supervisor is responsible for starting and supervising TimeSyncService\nprocesses. It ensures that the services restart properly if they crash.","ref":"DeribitEx.TimeSyncSupervisor.html"},{"type":"module","title":"Usage - DeribitEx.TimeSyncSupervisor","doc":"```elixir\n# Start the supervisor\n{:ok, supervisor_pid} = DeribitEx.TimeSyncSupervisor.start_link([])\n\n# Start a time sync service for a client\n{:ok, service_pid} = DeribitEx.TimeSyncSupervisor.start_service(client_pid)\n\n# Get the service name for a client\nservice_name = DeribitEx.TimeSyncSupervisor.service_name(client_pid)\n```","ref":"DeribitEx.TimeSyncSupervisor.html#module-usage"},{"type":"function","title":"DeribitEx.TimeSyncSupervisor.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"DeribitEx.TimeSyncSupervisor.html#child_spec/1"},{"type":"function","title":"DeribitEx.TimeSyncSupervisor.service_name/1","doc":"Gets the TimeSyncService for a specific client connection.","ref":"DeribitEx.TimeSyncSupervisor.html#service_name/1"},{"type":"function","title":"Parameters - DeribitEx.TimeSyncSupervisor.service_name/1","doc":"* `client_pid` - The PID of the Client connection","ref":"DeribitEx.TimeSyncSupervisor.html#service_name/1-parameters"},{"type":"function","title":"Returns - DeribitEx.TimeSyncSupervisor.service_name/1","doc":"* The name of the TimeSyncService for the given client","ref":"DeribitEx.TimeSyncSupervisor.html#service_name/1-returns"},{"type":"type","title":"DeribitEx.TimeSyncSupervisor.service_options/0","doc":"Options for starting a TimeSyncService.","ref":"DeribitEx.TimeSyncSupervisor.html#t:service_options/0"},{"type":"function","title":"DeribitEx.TimeSyncSupervisor.start_link/1","doc":"Starts the TimeSyncSupervisor.","ref":"DeribitEx.TimeSyncSupervisor.html#start_link/1"},{"type":"function","title":"Parameters - DeribitEx.TimeSyncSupervisor.start_link/1","doc":"* `init_arg` - Initialization arguments for the supervisor","ref":"DeribitEx.TimeSyncSupervisor.html#start_link/1-parameters"},{"type":"function","title":"Returns - DeribitEx.TimeSyncSupervisor.start_link/1","doc":"* `{:ok, pid}` - The PID of the started supervisor\n  * `{:error, reason}` - If the supervisor could not be started","ref":"DeribitEx.TimeSyncSupervisor.html#start_link/1-returns"},{"type":"function","title":"DeribitEx.TimeSyncSupervisor.start_service/2","doc":"Starts a new TimeSyncService for a given client connection.","ref":"DeribitEx.TimeSyncSupervisor.html#start_service/2"},{"type":"function","title":"Parameters - DeribitEx.TimeSyncSupervisor.start_service/2","doc":"* `client_pid` - The PID of the Client connection\n  * `opts` - Options for the time sync service (passed to TimeSyncService.start_link/2)","ref":"DeribitEx.TimeSyncSupervisor.html#start_service/2-parameters"},{"type":"function","title":"Returns - DeribitEx.TimeSyncSupervisor.start_service/2","doc":"* `{:ok, pid}` - The PID of the started service\n  * `{:error, reason}` - If the service could not be started","ref":"DeribitEx.TimeSyncSupervisor.html#start_service/2-returns"},{"type":"module","title":"DeribitEx.OrderContext","doc":"Manages order state preservation during token operations.\n\nThis module is responsible for:\n- Tracking orders associated with specific sessions\n- Preserving order information during session transitions\n- Providing a clean interface for order management integration\n- Supporting order state migration between sessions\n\nIntegrates with SessionContext to ensure order state continuity during\nauthentication changes and token operations.","ref":"DeribitEx.OrderContext.html"},{"type":"function","title":"DeribitEx.OrderContext.get_active_orders_for_session/2","doc":"Gets all active (open) orders from the specified session.","ref":"DeribitEx.OrderContext.html#get_active_orders_for_session/2"},{"type":"function","title":"Parameters - DeribitEx.OrderContext.get_active_orders_for_session/2","doc":"- `context`: The current OrderContext\n- `session_id`: The session ID to get active orders for","ref":"DeribitEx.OrderContext.html#get_active_orders_for_session/2-parameters"},{"type":"function","title":"Returns - DeribitEx.OrderContext.get_active_orders_for_session/2","doc":"- `{:ok, orders}`: List of active orders for the session","ref":"DeribitEx.OrderContext.html#get_active_orders_for_session/2-returns"},{"type":"function","title":"DeribitEx.OrderContext.get_orders_for_session/2","doc":"Gets all orders from the specified session.","ref":"DeribitEx.OrderContext.html#get_orders_for_session/2"},{"type":"function","title":"Parameters - DeribitEx.OrderContext.get_orders_for_session/2","doc":"- `context`: The current OrderContext\n- `session_id`: The session ID to get orders for","ref":"DeribitEx.OrderContext.html#get_orders_for_session/2-parameters"},{"type":"function","title":"Returns - DeribitEx.OrderContext.get_orders_for_session/2","doc":"- `{:ok, orders}`: List of orders for the session","ref":"DeribitEx.OrderContext.html#get_orders_for_session/2-returns"},{"type":"function","title":"DeribitEx.OrderContext.handle_session_transition/3","doc":"Handles a session transition by migrating order tracking.\n\nThis is called when tokens are exchanged or forked, to ensure\norder state is preserved across session changes.","ref":"DeribitEx.OrderContext.html#handle_session_transition/3"},{"type":"function","title":"Parameters - DeribitEx.OrderContext.handle_session_transition/3","doc":"- `context`: The current OrderContext\n- `prev_session`: The previous session that is being transitioned from\n- `new_session`: The new session being transitioned to","ref":"DeribitEx.OrderContext.html#handle_session_transition/3-parameters"},{"type":"function","title":"Returns - DeribitEx.OrderContext.handle_session_transition/3","doc":"- `{:ok, updated_context}`: Updated OrderContext with the session transition","ref":"DeribitEx.OrderContext.html#handle_session_transition/3-returns"},{"type":"function","title":"DeribitEx.OrderContext.new/0","doc":"Creates a new OrderContext instance.","ref":"DeribitEx.OrderContext.html#new/0"},{"type":"function","title":"Returns - DeribitEx.OrderContext.new/0","doc":"- A new empty OrderContext","ref":"DeribitEx.OrderContext.html#new/0-returns"},{"type":"type","title":"DeribitEx.OrderContext.order_entry/0","doc":"Tracks an order's association with a session.\n\n- `order_id`: The ID of the order from Deribit\n- `session_id`: The ID of the session that created the order\n- `instrument_name`: The instrument for this order (e.g., \"BTC-PERPETUAL\")\n- `direction`: Whether this is a \"buy\" or \"sell\" order\n- `status`: Current order status (e.g., \"open\", \"filled\", \"cancelled\")\n- `created_at`: When this order was created\n- `updated_at`: When this order was last updated\n- `metadata`: Additional order details that should be preserved","ref":"DeribitEx.OrderContext.html#t:order_entry/0"},{"type":"function","title":"DeribitEx.OrderContext.register_order/3","doc":"Registers a new order with the order context.","ref":"DeribitEx.OrderContext.html#register_order/3"},{"type":"function","title":"Parameters - DeribitEx.OrderContext.register_order/3","doc":"- `context`: The current OrderContext\n- `order`: The order information to register\n- `session_id`: The ID of the session creating this order","ref":"DeribitEx.OrderContext.html#register_order/3-parameters"},{"type":"function","title":"Returns - DeribitEx.OrderContext.register_order/3","doc":"- `{:ok, updated_context}`: Updated OrderContext with the new order","ref":"DeribitEx.OrderContext.html#register_order/3-returns"},{"type":"type","title":"DeribitEx.OrderContext.t/0","doc":"Represents the order context containing all tracked orders.\n\n- `orders`: Map of order_id to order entry information\n- `orders_by_session`: Map of session_id to list of order_ids\n- `active_session_id`: ID of the currently active session","ref":"DeribitEx.OrderContext.html#t:t/0"},{"type":"function","title":"DeribitEx.OrderContext.update_order/2","doc":"Updates an existing order in the context.","ref":"DeribitEx.OrderContext.html#update_order/2"},{"type":"function","title":"Parameters - DeribitEx.OrderContext.update_order/2","doc":"- `context`: The current OrderContext\n- `order`: The updated order information","ref":"DeribitEx.OrderContext.html#update_order/2-parameters"},{"type":"function","title":"Returns - DeribitEx.OrderContext.update_order/2","doc":"- `{:ok, updated_context}`: Updated OrderContext with the modified order\n- `{:error, :not_found}`: If the order doesn't exist in the context","ref":"DeribitEx.OrderContext.html#update_order/2-returns"},{"type":"module","title":"DeribitEx.Telemetry","doc":"Telemetry events for the DeribitEx library.\n\nThis module provides a consistent interface for emitting telemetry events\nthroughout the library. Use these functions instead of calling :telemetry.execute\ndirectly to ensure consistent event naming and metadata structure.","ref":"DeribitEx.Telemetry.html"},{"type":"module","title":"Event Categories - DeribitEx.Telemetry","doc":"DeribitEx emits telemetry events in the following categories:\n\n- Connection: Events related to WebSocket connection lifecycle\n- RPC: Events for request/response operations\n- Auth: Authentication-related events\n- Subscription: Channel subscription events\n- Order Context: Order tracking events","ref":"DeribitEx.Telemetry.html#module-event-categories"},{"type":"module","title":"Example Usage - DeribitEx.Telemetry","doc":"```elixir\n:telemetry.attach(\n  \"deribit-auth-handler\",\n  [:deribit_ex, :auth, :success],\n  fn name, measurements, metadata, _config ->\n    # Process authentication success event\n  end,\n  nil\n)\n```","ref":"DeribitEx.Telemetry.html#module-example-usage"},{"type":"type","title":"DeribitEx.Telemetry.connection/0","doc":"Connection identifier, typically the WebSocket client PID.","ref":"DeribitEx.Telemetry.html#t:connection/0"},{"type":"function","title":"DeribitEx.Telemetry.emit_auth_failure/3","doc":"Emits a telemetry event when authentication fails.","ref":"DeribitEx.Telemetry.html#emit_auth_failure/3"},{"type":"function","title":"Parameters - DeribitEx.Telemetry.emit_auth_failure/3","doc":"- `connection`: The WebSocket connection identifier\n- `reason`: The reason for the authentication failure\n- `metadata`: Additional metadata to include with the event","ref":"DeribitEx.Telemetry.html#emit_auth_failure/3-parameters"},{"type":"function","title":"DeribitEx.Telemetry.emit_auth_success/2","doc":"Emits a telemetry event when authentication is successful.","ref":"DeribitEx.Telemetry.html#emit_auth_success/2"},{"type":"function","title":"Parameters - DeribitEx.Telemetry.emit_auth_success/2","doc":"- `connection`: The WebSocket connection identifier\n- `metadata`: Additional metadata to include with the event","ref":"DeribitEx.Telemetry.html#emit_auth_success/2-parameters"},{"type":"function","title":"DeribitEx.Telemetry.emit_connection_closed/3","doc":"Emits a telemetry event when a connection is closed.","ref":"DeribitEx.Telemetry.html#emit_connection_closed/3"},{"type":"function","title":"Parameters - DeribitEx.Telemetry.emit_connection_closed/3","doc":"- `connection`: The WebSocket connection identifier\n- `reason`: The reason for the connection closure\n- `metadata`: Additional metadata to include with the event","ref":"DeribitEx.Telemetry.html#emit_connection_closed/3-parameters"},{"type":"function","title":"DeribitEx.Telemetry.emit_connection_opened/2","doc":"Emits a telemetry event when a connection is established.","ref":"DeribitEx.Telemetry.html#emit_connection_opened/2"},{"type":"function","title":"Parameters - DeribitEx.Telemetry.emit_connection_opened/2","doc":"- `connection`: The WebSocket connection identifier\n- `metadata`: Additional metadata to include with the event","ref":"DeribitEx.Telemetry.html#emit_connection_opened/2-parameters"},{"type":"function","title":"DeribitEx.Telemetry.emit_order_registered/3","doc":"Emits a telemetry event when an order is registered.","ref":"DeribitEx.Telemetry.html#emit_order_registered/3"},{"type":"function","title":"Parameters - DeribitEx.Telemetry.emit_order_registered/3","doc":"- `order_id`: The ID of the order\n- `session_id`: The session ID that the order belongs to\n- `metadata`: Additional metadata to include with the event","ref":"DeribitEx.Telemetry.html#emit_order_registered/3-parameters"},{"type":"function","title":"DeribitEx.Telemetry.emit_order_updated/4","doc":"Emits a telemetry event when an order is updated.","ref":"DeribitEx.Telemetry.html#emit_order_updated/4"},{"type":"function","title":"Parameters - DeribitEx.Telemetry.emit_order_updated/4","doc":"- `order_id`: The ID of the order\n- `session_id`: The session ID that the order belongs to\n- `status`: The new status of the order\n- `metadata`: Additional metadata to include with the event","ref":"DeribitEx.Telemetry.html#emit_order_updated/4-parameters"},{"type":"function","title":"DeribitEx.Telemetry.emit_rpc_request/3","doc":"Emits a telemetry event when an RPC request is sent.","ref":"DeribitEx.Telemetry.html#emit_rpc_request/3"},{"type":"function","title":"Parameters - DeribitEx.Telemetry.emit_rpc_request/3","doc":"- `type`: The type of RPC request (:auth, :public, :private, etc.)\n- `method`: The RPC method name\n- `metadata`: Additional metadata to include with the event","ref":"DeribitEx.Telemetry.html#emit_rpc_request/3-parameters"},{"type":"function","title":"DeribitEx.Telemetry.emit_rpc_response/4","doc":"Emits a telemetry event when an RPC response is received.","ref":"DeribitEx.Telemetry.html#emit_rpc_response/4"},{"type":"function","title":"Parameters - DeribitEx.Telemetry.emit_rpc_response/4","doc":"- `type`: The type of RPC request that this is a response to\n- `method`: The RPC method name\n- `duration`: The duration of the request in native time units\n- `metadata`: Additional metadata to include with the event","ref":"DeribitEx.Telemetry.html#emit_rpc_response/4-parameters"},{"type":"function","title":"DeribitEx.Telemetry.emit_session_transition/4","doc":"Emits a telemetry event when a session transition occurs.","ref":"DeribitEx.Telemetry.html#emit_session_transition/4"},{"type":"function","title":"Parameters - DeribitEx.Telemetry.emit_session_transition/4","doc":"- `prev_session_id`: The previous session ID\n- `new_session_id`: The new session ID\n- `transition_type`: The type of transition (:refresh, :exchange, :fork, :logout)\n- `metadata`: Additional metadata to include with the event","ref":"DeribitEx.Telemetry.html#emit_session_transition/4-parameters"},{"type":"function","title":"DeribitEx.Telemetry.emit_subscription_created/2","doc":"Emits a telemetry event when a subscription is created.","ref":"DeribitEx.Telemetry.html#emit_subscription_created/2"},{"type":"function","title":"Parameters - DeribitEx.Telemetry.emit_subscription_created/2","doc":"- `channel`: The channel name that was subscribed to\n- `metadata`: Additional metadata to include with the event","ref":"DeribitEx.Telemetry.html#emit_subscription_created/2-parameters"},{"type":"function","title":"DeribitEx.Telemetry.emit_subscription_removed/2","doc":"Emits a telemetry event when a subscription is removed.","ref":"DeribitEx.Telemetry.html#emit_subscription_removed/2"},{"type":"function","title":"Parameters - DeribitEx.Telemetry.emit_subscription_removed/2","doc":"- `channel`: The channel name that was unsubscribed from\n- `metadata`: Additional metadata to include with the event","ref":"DeribitEx.Telemetry.html#emit_subscription_removed/2-parameters"},{"type":"type","title":"DeribitEx.Telemetry.metadata/0","doc":"Generic metadata map for telemetry events.","ref":"DeribitEx.Telemetry.html#t:metadata/0"},{"type":"type","title":"DeribitEx.Telemetry.rpc_type/0","doc":"RPC request types.","ref":"DeribitEx.Telemetry.html#t:rpc_type/0"},{"type":"type","title":"DeribitEx.Telemetry.session_id/0","doc":"Session identifier for tracking session state.","ref":"DeribitEx.Telemetry.html#t:session_id/0"},{"type":"type","title":"DeribitEx.Telemetry.transition_type/0","doc":"Types of session transitions.","ref":"DeribitEx.Telemetry.html#t:transition_type/0"},{"type":"extras","title":"DeribitEx","doc":"# DeribitEx\n\nAn Elixir library for interacting with the Deribit cryptocurrency exchange API via WebSocket.\n\n[![Hex.pm](https://img.shields.io/hexpm/v/deribit_ex.svg)](https://hex.pm/packages/deribit_ex)\n[![Documentation](https://img.shields.io/badge/docs-hexpm-blue.svg)](https://hexdocs.pm/deribit_ex)\n[![License](https://img.shields.io/hexpm/l/deribit_ex.svg)](https://github.com/username/deribit_ex/blob/master/LICENSE)","ref":"readme.html"},{"type":"extras","title":"Features - DeribitEx","doc":"- **WebSocket-based communication**: Efficient and real-time communication with Deribit API\n- **Authentication management**: Automatic token refresh, exchange, and forking\n- **Request/response handling**: Clean JSON-RPC implementation\n- **Subscription management**: Easy subscription to public and private channels\n- **Automatic resubscription**: After reconnection or authentication changes\n- **Rate limiting**: Adaptive rate limiting to avoid 429 errors\n- **Time synchronization**: Keeps local time in sync with server time\n- **Cancel-on-disconnect**: Automatic setup of safety measures\n- **Telemetry integration**: Comprehensive event instrumentation","ref":"readme.html#features"},{"type":"extras","title":"Installation - DeribitEx","doc":"Add `deribit_ex` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:deribit_ex, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - DeribitEx","doc":"Configure your Deribit API credentials in your config:\n\n```elixir\n# config/config.exs\nconfig :deribit_ex,\n  client_id: System.get_env(\"DERIBIT_CLIENT_ID\"),\n  client_secret: System.get_env(\"DERIBIT_CLIENT_SECRET\"),\n  test_mode: true # Set to false for production API\n\n# Optional settings\nconfig :deribit_ex,\n  rate_limit_mode: :normal, # Options: :cautious, :normal, :aggressive\n  request_timeout: 5000     # Default timeout in milliseconds\n```\n\nOr provide credentials directly when connecting:\n\n```elixir\n{:ok, client} = DeribitEx.Client.connect(\n  client_id: \"your_client_id\",\n  client_secret: \"your_client_secret\",\n  test_mode: true\n)\n```","ref":"readme.html#configuration"},{"type":"extras","title":"Usage Examples - DeribitEx","doc":"","ref":"readme.html#usage-examples"},{"type":"extras","title":"Connecting to Deribit - DeribitEx","doc":"```elixir\n# Connect with configured credentials\n{:ok, client} = DeribitEx.Client.connect()\n\n# Or connect with explicit credentials\n{:ok, client} = DeribitEx.Client.connect(\n  client_id: \"your_client_id\",\n  client_secret: \"your_client_secret\"\n)\n```","ref":"readme.html#connecting-to-deribit"},{"type":"extras","title":"Making API Requests - DeribitEx","doc":"```elixir\n# Get available instruments\n{:ok, instruments} = DeribitEx.Client.get_instruments(client, %{\n  currency: \"BTC\",\n  kind: \"future\"\n})\n\n# Get account summary\n{:ok, summary} = DeribitEx.Client.get_account_summary(client, %{\n  currency: \"BTC\"\n})\n\n# Place an order\n{:ok, order} = DeribitEx.Client.buy(client, %{\n  instrument_name: \"BTC-PERPETUAL\",\n  amount: 100,\n  type: \"limit\",\n  price: 30000,\n  post_only: true\n})\n```","ref":"readme.html#making-api-requests"},{"type":"extras","title":"Subscriptions - DeribitEx","doc":"```elixir\n# Define a callback module\ndefmodule MyApp.DeribitHandler do\n  use GenServer\n\n  def start_link(_opts) do\n    GenServer.start_link(__MODULE__, %{})\n  end\n\n  def init(state) do\n    {:ok, state}\n  end\n\n  # Handle subscription notifications\n  def handle_info({:deribit_notification, channel, data}, state) do\n    IO.puts(\"Received notification from #{channel}\")\n    # Process the data\n    {:noreply, state}\n  end\nend\n\n# Start the handler\n{:ok, handler_pid} = MyApp.DeribitHandler.start_link([])\n\n# Subscribe to orderbook updates\n{:ok, _sub_id} = DeribitEx.Client.subscribe_book(\n  client,\n  \"BTC-PERPETUAL\",\n  handler_pid\n)\n\n# Subscribe to your account updates (requires authentication)\n{:ok, _sub_id} = DeribitEx.Client.subscribe_user_orders(\n  client,\n  \"BTC\",\n  handler_pid\n)\n\n# Unsubscribe when done\n:ok = DeribitEx.Client.unsubscribe(client, sub_id)\n```","ref":"readme.html#subscriptions"},{"type":"extras","title":"Token Management - DeribitEx","doc":"```elixir\n# Exchange your token to access a sub-account\n{:ok, _new_client} = DeribitEx.Client.exchange_token(client, \"subaccount_name\")\n\n# Create a named session\n{:ok, _named_client} = DeribitEx.Client.fork_token(client, \"session_name\")\n```","ref":"readme.html#token-management"},{"type":"extras","title":"Telemetry Events - DeribitEx","doc":"DeribitEx emits telemetry events that you can handle in your application:\n\n```elixir\n:telemetry.attach(\n  \"deribit-request-handler\",\n  [:deribit_ex, :request, :stop],\n  fn name, measurements, metadata, _config ->\n    # Handle request completion event\n  end,\n  nil\n)\n```\n\nKey events include:\n- `[:deribit_ex, :request, :start]`\n- `[:deribit_ex, :request, :stop]`\n- `[:deribit_ex, :subscription, :notification]`\n- `[:deribit_ex, :auth, :refresh]`\n- `[:deribit_ex, :rate_limit, :delay]`","ref":"readme.html#telemetry-events"},{"type":"extras","title":"Testing with Deribit Testnet - DeribitEx","doc":"The library uses Deribit's testnet when `test_mode: true` is set. You can create a testnet account at [test.deribit.com](https://test.deribit.com/).","ref":"readme.html#testing-with-deribit-testnet"},{"type":"extras","title":"Documentation - DeribitEx","doc":"Full documentation is available at [HexDocs](https://hexdocs.pm/deribit_ex).","ref":"readme.html#documentation"},{"type":"extras","title":"License - DeribitEx","doc":"DeribitEx is released under the MIT License. See the [LICENSE](LICENSE) file for details.","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n## [0.2.0] - 2025-05-22","ref":"changelog.html"},{"type":"extras","title":"Added - Changelog","doc":"- Comprehensive coding and testing guidelines in CLAUDE.md\n- Enhanced documentation with code quality standards and integration testing requirements\n- Test request and heartbeat message handling for backward compatibility","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- Updated websockex_nova dependency to ~> 0.1.1 for latest features\n- Simplified heartbeat handling to be stateless for improved performance\n- Moved test_request handling from message level to frame level for better reliability\n- Removed FrameHandler alias and behavior to simplify module structure","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - Changelog","doc":"- Corrected config module references in TimeSyncService tests\n- Fixed connection PID handling in ReconnectMonitor tests\n- Updated adapter implementation to use ConnectionHandler instead of FrameHandler\n\n## [0.1.0] - 2025-05-21","ref":"changelog.html#fixed"},{"type":"extras","title":"Added - Changelog","doc":"- Initial release of DeribitEx\n- WebSocket-based client for Deribit API\n- Authentication and token management\n- Request/response handling via JSON-RPC\n- Subscription and resubscription handling\n- Time synchronization with server\n- Rate limiting implementation\n- Cancel-on-disconnect safety features\n- Telemetry integration for monitoring\n- Comprehensive test suite","ref":"changelog.html#added-1"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.1"}}